@@ -41,11 +41,11 @@
  *                MdcHashSDBM()           - Get hash using sdbm method     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-algori.c,v 1.87 2011/12/27 00:46:06 enlf Exp $ 
+/* $Id$
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2019 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -86,7 +86,7 @@
 #include "medcon.h"
 
 /****************************************************************************
-                              D E F I N E S 
+                              D E F I N E S
 ****************************************************************************/
 
 #define maxmin(x, max, min)          { maxmin_t=(x);                     \
@@ -143,26 +143,26 @@ READING:   host     infile    swap
 -----------------------------------
            big0      big0      0
            big0      little1   1
-           little1   big0      1 
-           little1   little1   0 
+           little1   big0      1
+           little1   little1   0
 ----------------------------------
 READING:   host  XOR file  =  swap
 
 
-WRITING:   host     outfile   swap 
+WRITING:   host     outfile   swap
 ----------------------------------
            big0      big0      0
            little1   big0      1
 
-           big0      little1   1 
-           little1   little1   0 
+           big0      little1   1
+           little1   little1   0
 ----------------------------------
 WRITING    host  XOR file  =  swap
 */
 
-int MdcDoSwap(void) 
+int MdcDoSwap(void)
 {
-  return(MDC_HOST_ENDIAN^MDC_FILE_ENDIAN); 
+  return(MDC_HOST_ENDIAN^MDC_FILE_ENDIAN);
 }
 
 int MdcHostBig(void)
@@ -175,7 +175,7 @@ void MdcSwapBytes(Uint8 *ptr, int bytes)
 {
   int i, j;
 
-  if ( MdcDoSwap() ) 
+  if ( MdcDoSwap() )
     for (i=0,j=bytes-1;i < (bytes/2); i++, j--) {
        ptr[i]^=ptr[j]; ptr[j]^=ptr[i]; ptr[i]^=ptr[j];
     }
@@ -191,9 +191,9 @@ void MdcForceSwap(Uint8 *ptr, int bytes)
 }
 
 void MdcIEEEfl_to_VAXfl(float *f)
-{ 
+{
   Uint16 exp;
-  union { 
+  union {
           Uint16 t[2];
           float t4;
   } test;
@@ -238,11 +238,11 @@ void MdcVAXfl_to_IEEEfl(float *f)
   if (MdcHostBig()) {
     Uint16 temp;
     temp = number.n[0]; number.n[0]=number.n[1]; number.n[1]=temp;
-  } 
+  }
 
   MdcSwapBytes((Uint8 *)&number.n4,4);
 
-  if ((number.n[0] != 0) || (number.n[1] != 0) ) { 
+  if ((number.n[0] != 0) || (number.n[1] != 0) ) {
     t1 = number.n[0] & 0x80ff;
     t2 = (((number.n[0])&0x7f00)+0xff00)&0x7f00;
     test.t3 = (t1+t2)<<16;
@@ -291,7 +291,7 @@ int MdcFixDouble(double *ref)
 
 int MdcType2Bytes(int type)
 {
-  int bytes = 0; 
+  int bytes = 0;
 
   switch (type) {
 
@@ -308,15 +308,13 @@ int MdcType2Bytes(int type)
     case BIT32_U:
     case FLT32  :
     case VAXFL32: bytes = 4; break;
-   
+
     case ASCII  : /* read as double */
-#ifdef HAVE_8BYTE_INT
     case BIT64_S:
     case BIT64_U:
-#endif
     case FLT64  : bytes = 8; break;
   }
- 
+
   return(bytes);
 
 }
@@ -325,7 +323,7 @@ int MdcType2Bytes(int type)
 
 int MdcType2Bits(int type)
 {
-  int bits = 0; 
+  int bits = 0;
 
   switch (type) {
 
@@ -345,13 +343,11 @@ int MdcType2Bits(int type)
     case VAXFL32: bits = 32; break;
 
     case ASCII  : /* read as double */
-#ifdef HAVE_8BYTE_INT
     case BIT64_S:
     case BIT64_U:
-#endif
     case FLT64  : bits = 64; break;
   }
- 
+
   return(bits);
 
 }
@@ -366,10 +362,8 @@ double MdcTypeIntMax(int type)
     case BIT16_U: return(65535.);
     case BIT32_S: return(2147483647.);
     case BIT32_U: return(4294967295.);
-#ifdef HAVE_8BYTE_INT
     case BIT64_S: return(9223372036854775807.);
     case BIT64_U: return(18446744073709551615.);
-#endif
 
   }
 
@@ -392,7 +386,7 @@ float MdcSingleImageDuration(FILEINFO *fi, Uint32 frame)
 
   slices = (float)dd->nr_of_slices;
 
-  /* planar -> each slice  separate: Tslice = Tframe/Nslices */  
+  /* planar -> each slice  separate: Tslice = Tframe/Nslices */
   /* tomo   -> all  slices at once : Tslice = Tframe         */
   duration  = dd->time_frame_duration;                   /* no frame delay  */
   duration -= ((slices - 1) * dd->delay_slices);         /* no slice delays */
@@ -402,11 +396,11 @@ float MdcSingleImageDuration(FILEINFO *fi, Uint32 frame)
 }
 
 /*
- pixel by pixel processes: yes, THE all in one routine 
-     - swap bytes 
-     - make positive 
+ pixel by pixel processes: yes, THE all in one routine
+     - swap bytes
+     - make positive
      - get global & image  variables
- check some parameters 
+ check some parameters
 
  WARNING: double pixel types may get corrupted quantification values
           because our quantification is stripped down to a float!!
@@ -418,7 +412,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
   STATIC_DATA *sd;
   Uint32 f, i, j, n, s, t;
   float start, duration;
-  double fmin=0., fmax=0., qfmin=0., qfmax=0.; 
+  double fmin=0., fmax=0., qfmin=0., qfmax=0.;
   char *msg;
   int FixWarn=0;
 
@@ -433,7 +427,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
      MdcDebugPrint("dim[] TEST : fi->dim[%d] = %u",i,fi->dim[i]);
      t *= fi->dim[i];
   }
- 
+
   if (fi->number != t) {
     /* return("Internal Error ## Improper fi->dim values"); */
 
@@ -445,7 +439,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
 
     fi->dim[0] = 3; fi->dim[3] = fi->number;
     for (i=4; i<MDC_MAX_DIMS; i++) fi->dim[i] = 1;
- 
+
   }
 
 
@@ -460,7 +454,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
 
   if (fi->dynnr > 0) {
     /* check number of slices */
-    for (i=0, t=0; i<fi->dynnr; i++) { 
+    for (i=0, t=0; i<fi->dynnr; i++) {
        t += fi->dyndata[i].nr_of_slices;
     }
     if (t != fi->number) {
@@ -481,7 +475,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
 
        /* update frame_start values */
        if ((f > 0) && (dd->time_frame_start == 0.)) {
-         dd->time_frame_start = fi->dyndata[f-1].time_frame_start 
+         dd->time_frame_start = fi->dyndata[f-1].time_frame_start
                               + fi->dyndata[f-1].time_frame_delay
                               + fi->dyndata[f-1].time_frame_duration;
        }
@@ -496,10 +490,10 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
           id->frame_number = f+1; /* must be one based */
           id->slice_start    = start;
           if (fi->planar == MDC_YES) start += (duration + dd->delay_slices);
-       }        
+       }
     }
   }
- 
+
   /* fill in orientation information */
   if (strcmp(fi->pat_pos,"Unknown") == 0)
     strcpy(fi->pat_pos,MdcGetStrPatPos(fi->pat_slice_orient));
@@ -519,7 +513,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
      id = &fi->image[j];
 
      /* check dimension/pixeltype values */
-     if ( id->width == 0 || id->height == 0 || 
+     if ( id->width == 0 || id->height == 0 ||
           id->bits == 0  || id->type == 0   ||
           id->buf == NULL) {
        return("Internal Error ## Improper IMG_DATA values");
@@ -542,7 +536,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
        fi->mheight = id->height;
      }else{
        if (id->width != fi->mwidth) {
-         fi->diff_size = MDC_YES; 
+         fi->diff_size = MDC_YES;
          if (id->width > fi->mwidth ) fi->mwidth = id->width;
        }
        if (id->height != fi->mheight) {
@@ -577,7 +571,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
       fi->pixdim[0] == 4.0 ||
       fi->pixdim[0] == 5.0 ||
       fi->pixdim[0] == 6.0 ||
-      fi->pixdim[0] == 7.0 ) { 
+      fi->pixdim[0] == 7.0 ) {
     for (t=1; t<=(Int32)fi->pixdim[0]; t++) {
        if (fi->pixdim[t] <= 0.0 ) fi->pixdim[t] = 1.;
     }
@@ -596,7 +590,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
 
   if (MDC_PROGRESS) MdcProgress(MDC_PROGRESS_BEGIN,0.,"Processing images:");
 
-  /* max/min, endian, quantitation */ 
+  /* max/min, endian, quantitation */
   for (j=0; j<fi->number; j++) {
 
      if (MDC_PROGRESS) MdcProgress(MDC_PROGRESS_INCR,1./(float)fi->number,NULL);
@@ -608,7 +602,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
      if (MDC_FORCE_RESCALE) {
        id->quant_scale = mdc_si_slope;
        id->calibr_fctr = 1.;
-       id->intercept   = mdc_si_intercept; 
+       id->intercept   = mdc_si_intercept;
      }
 
      if (MDC_QUANTIFY) {
@@ -659,7 +653,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
        }
        break;
       case BIT8_S:
-       { 
+       {
          Int8 *pix = (Int8 *) id->buf, pix0;
          Int8 max, min, maxmin_t;
 
@@ -695,7 +689,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
          memcpy((void *)&pix0,(void *)pix,2);
          MdcSwapBytes((Uint8 *)&pix0, 2);
 
-         /* init max,min values */ 
+         /* init max,min values */
          min = pix0;
          max = pix0;
          if (j == 0) {
@@ -797,9 +791,8 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
          id->min = (double) min;
        }
        break;
-#ifdef HAVE_8BYTE_INT
       case BIT64_U:
-       { 
+       {
          Uint64 *pix = (Uint64 *) id->buf, pix0;
          Uint64 max, min, maxmin_t;
 
@@ -854,7 +847,6 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
          id->min = (double) min;
        }
        break;
-#endif
       case FLT32:
        {
          float *pix = (float *) id->buf, pix0;
@@ -949,8 +941,8 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
      }else{
        if ( id->qmin < fi->qglmin) fi->qglmin = id->qmin;
      }
-     /* handle quantified global max values */ 
-     if (j == 0) { 
+     /* handle quantified global max values */
+     if (j == 0) {
        fi->qglmax = id->qmax;
      }else{
        if ( id->qmax > fi->qglmax ) fi->qglmax = id->qmax;
@@ -959,9 +951,9 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
      /* handle the max/min values for the frame group */
      if ( (j % fi->dim[3]) == 0 ) {
        /* a frame boundary */
-       if (j == 0) { 
+       if (j == 0) {
          /* the beginning frame group */
-         fmin  = id->min;  fmax  = id->max; 
+         fmin  = id->min;  fmax  = id->max;
          qfmin = id->qmin; qfmax = id->qmax;
        }else{
          /* new frame group, fill in the values for previous frame */
@@ -975,7 +967,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
          fmin  = id->min;  fmax  = id->max;
          qfmin = id->qmin; qfmax = id->qmax;
        }
-     }else{ 
+     }else{
        /* inside a frame group, determine min/max values */
        if (id->min < fmin ) fmin = id->min;
        if (id->max > fmax ) fmax = id->max;
@@ -983,7 +975,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
        if (id->qmin < qfmin ) qfmin = id->qmin;
        if (id->qmax > qfmax ) qfmax = id->qmax;
 
-     } 
+     }
 
   }
 
@@ -991,7 +983,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
   if (FixWarn) MdcPrntWarn("Fixed pixels with bad float value (= set to zero)");
 
   /* don't forget to fill in the min/max values for the last frame group */
-  for (t=j - fi->dim[3]; t<j ; t++) {        
+  for (t=j - fi->dim[3]; t<j ; t++) {
      idprev = &fi->image[t];
 
      idprev->fmin  = fmin;  idprev->fmax  = fmax;
@@ -1016,12 +1008,12 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
     }
   }
 
-  /* from here on, endianess is host based */
-  MDC_FILE_ENDIAN = MDC_HOST_ENDIAN; 
+  /* from here on, endianness is host based */
+  MDC_FILE_ENDIAN = MDC_HOST_ENDIAN;
 
   return(NULL);
 
-} 
+}
 
 double MdcGetDoublePixel(Uint8 *buf, int type)
 {
@@ -1064,7 +1056,6 @@ double MdcGetDoublePixel(Uint8 *buf, int type)
            value = (double)pix[0];
         }
         break;
-#ifdef HAVE_8BYTE_INT
     case BIT64_U:
         {
            Uint64 *pix = (Uint64 *)buf;
@@ -1077,7 +1068,6 @@ double MdcGetDoublePixel(Uint8 *buf, int type)
            value = (double)pix[0];
         }
         break;
-#endif
     case FLT32:
         {
            float *pix = (float *)buf;
@@ -1104,9 +1094,9 @@ void MdcPutDoublePixel(Uint8 *buf, double pix, int type)
   case BIT8_S:
    {
      Int8 c = (Int8) pix;
-     buf[0] = c; 
+     buf[0] = c;
    }
-   break; 
+   break;
   case BIT8_U:
    {
      Uint8 c = (Uint8) pix;
@@ -1116,7 +1106,7 @@ void MdcPutDoublePixel(Uint8 *buf, double pix, int type)
   case BIT16_S:
    {
      Int16 c = (Int16) pix;
-     memcpy(buf,(Uint8 *)&c,bytes); 
+     memcpy(buf,(Uint8 *)&c,bytes);
    }
    break;
   case BIT16_U:
@@ -1127,17 +1117,16 @@ void MdcPutDoublePixel(Uint8 *buf, double pix, int type)
    break;
   case BIT32_S:
    {
-     Int32 c = (Int32) pix; 
-     memcpy(buf,(Uint8 *)&c,bytes); 
+     Int32 c = (Int32) pix;
+     memcpy(buf,(Uint8 *)&c,bytes);
    }
    break;
   case BIT32_U:
    {
      Uint32 c = (Uint32) pix;
-     memcpy(buf,(Uint8 *)&c,bytes); 
+     memcpy(buf,(Uint8 *)&c,bytes);
    }
    break;
-#ifdef HAVE_8BYTE_INT
   case BIT64_S:
    {
      Int64 c = (Int64) pix;
@@ -1150,17 +1139,16 @@ void MdcPutDoublePixel(Uint8 *buf, double pix, int type)
      memcpy(buf,(Uint8 *)&c,bytes);
    }
    break;
-#endif 
   case FLT32:
    {
      float c = (float) pix;
-     memcpy(buf,(Uint8 *)&c,bytes); 
+     memcpy(buf,(Uint8 *)&c,bytes);
    }
    break;
   case FLT64:
    {
      double c = (double) pix;
-     memcpy(buf,(Uint8 *)&c,bytes); 
+     memcpy(buf,(Uint8 *)&c,bytes);
    }
    break;
  }
@@ -1172,9 +1160,9 @@ int MdcDoSimpleCast(double minv, double maxv, double negmin, double posmax)
   Int32 casted;
 
   /* Rescaling to new integer values (Int32, Int16, Uint8): when original
-   * values are integers and within the range of the new pixel type, a 
+   * values are integers and within the range of the new pixel type, a
    * simple cast would do - without rescaling
-   *                      - preserving original values 
+   *                      - preserving original values
    */
 
   if (MDC_ALLOW_CAST == MDC_NO) return(MDC_NO);
@@ -1258,7 +1246,7 @@ Uint8 *MdcGetResizedImage(FILEINFO *fi,Uint8 *buffer,int type,Uint32 img)
       MdcFree(maxbuf);
       return(NULL);
     }
-     
+
     pbuf = lbuf;
     for (p = 0; p < lpad; p++) {
        MdcPutDoublePixel(pbuf,pval,type);
@@ -1269,9 +1257,9 @@ Uint8 *MdcGetResizedImage(FILEINFO *fi,Uint8 *buffer,int type,Uint32 img)
     rbuf = malloc(bytes * rpad);
     if (rbuf == NULL) {
       MdcFree(maxbuf); MdcFree(lbuf);
-      return(NULL); 
+      return(NULL);
     }
-     
+
     pbuf = rbuf;
     for (p = 0; p < rpad; p++) {
        MdcPutDoublePixel(pbuf,pval,type);
@@ -1279,7 +1267,7 @@ Uint8 *MdcGetResizedImage(FILEINFO *fi,Uint8 *buffer,int type,Uint32 img)
     }
   }
 
-  if ((tpad > 0) || (bpad > 0)) { 
+  if ((tpad > 0) || (bpad > 0)) {
     linebuf = malloc(bytes * linepad);
     if (linebuf == NULL) {
       MdcFree(maxbuf); MdcFree(lbuf); MdcFree(rbuf);
@@ -1338,7 +1326,7 @@ Uint8 *MdcGetDisplayImage(FILEINFO *fi, Uint32 img)
      /* RGB */
      width  = fi->image[img].width;
      height = fi->image[img].height;
-   
+
      bytes = width * height * 3;
 
      buf = malloc(bytes);
@@ -1430,7 +1418,7 @@ Uint8 *MdcMakeBIT8_U(Uint8 *cbuf, FILEINFO *fi, Uint32 img)
   if (DO_QUANT_CALIBR) {
     id->rescaled_fctr = (min < 0.) ? 1. : 1./scale;
     id->rescaled_slope= 1./scale;
-    id->rescaled_intercept = min; 
+    id->rescaled_intercept = min;
     idmax = id->qmax; idmin = id->qmin;
   }else{
     id->rescaled_fctr = 1.;
@@ -1443,7 +1431,7 @@ Uint8 *MdcMakeBIT8_U(Uint8 *cbuf, FILEINFO *fi, Uint32 img)
 
   return(buf);
 
-} 
+}
 
 /* converts to Uint8 */
 Uint8 *MdcGetImgBIT8_U(FILEINFO *fi, Uint32 img)
@@ -1456,9 +1444,9 @@ Uint8 *MdcGetImgBIT8_U(FILEINFO *fi, Uint32 img)
 
   buffer=MdcMakeBIT8_U(buffer,fi,img);
 
-  return((Uint8 *)buffer); 
-  
-} 
+  return((Uint8 *)buffer);
+
+}
 
 Uint8 *MdcMakeBIT16_S(Uint8 *cbuf, FILEINFO *fi, Uint32 img)
 {
@@ -1525,7 +1513,7 @@ Uint8 *MdcMakeBIT16_S(Uint8 *cbuf, FILEINFO *fi, Uint32 img)
 
      /* get pixel value */
      pixval = MdcGetDoublePixel(pixel,id->type);
-     if (DO_QUANT_CALIBR) { 
+     if (DO_QUANT_CALIBR) {
        pixval *= (double)id->rescale_slope;
        pixval += (double)id->rescale_intercept;
      }
@@ -1578,10 +1566,9 @@ Uint8 *MdcMakeBIT32_S(Uint8 *cbuf, FILEINFO *fi, Uint32 img)
   Int32 *buf = (Int32 *)cbuf;
   Uint32 i, n = id->width * id->height;
   double pixval, min, max, idmin, idmax, scale=1.0;
-  double SMAX, UMAX, negmin, posmax;
+  double SMAX, negmin, posmax;
   float newval;
 
-  UMAX = (double)(1 <<  BITS);     /* 4294967296 */
   SMAX = (double)(1 << (BITS-1));  /* 2147483648 */
 
   /* get proper maximum/minimum value */
@@ -1665,7 +1652,7 @@ Uint8 *MdcMakeBIT32_S(Uint8 *cbuf, FILEINFO *fi, Uint32 img)
 Uint8 *MdcGetImgBIT32_S(FILEINFO *fi, Uint32 img)
 {
   IMG_DATA *id = &fi->image[img];
-  Uint32 size = id->width * id->height * MdcType2Bytes(BIT32_S); 
+  Uint32 size = id->width * id->height * MdcType2Bytes(BIT32_S);
   Uint8 *buffer;
 
   if ( (buffer=(Uint8 *)malloc(size)) == NULL ) return NULL;
@@ -1690,14 +1677,14 @@ Uint8 *MdcMakeFLT32(Uint8 *cbuf, FILEINFO *fi, Uint32 img)
   /* get proper maximum/minimum value */
   if (MDC_QUANTIFY || MDC_CALIBRATE) {
     /* do the real quantification */
-    DO_QUANT_CALIBR = MDC_YES; 
+    DO_QUANT_CALIBR = MDC_YES;
     min = id->qmin;
-    max = id->qmax;            
+    max = id->qmax;
 
-    if (id->type == FLT64) { 
+    if (id->type == FLT64) {
       /* probably be too big for float. if global too */
       /* big, don't quantify an image but do a simple */
-      /* downscaling to float and warn the user!      */ 
+      /* downscaling to float and warn the user!      */
       if (fi->qglmax > 3.40282347e+38) {
         MdcPrntWarn("Values `double' too big for `quantified float'");
         DO_QUANT_CALIBR = MDC_NO;
@@ -1725,9 +1712,9 @@ Uint8 *MdcMakeFLT32(Uint8 *cbuf, FILEINFO *fi, Uint32 img)
     scale = (double)id->rescale_slope; /* anything else fits in float */
   }else{
     /* try preserving pixel values with simple cast */
-    if (id->type <= FLT32 ) { 
+    if (id->type <= FLT32 ) {
       scale = 1.; DO_CAST = MDC_YES; /* ok, integers */
-    }else if ( id->type == FLT64 && fabs(fi->glmax) < 3.40282347e+38 
+    }else if ( id->type == FLT64 && fabs(fi->glmax) < 3.40282347e+38
                                  && fabs(fi->glmin) > 1e-37 ) {
       scale = 1.; DO_CAST = MDC_YES; /* ok, doubles fit in float */
     }else{ /* need rescaling: 0 -> MAX_FLOAT*/
@@ -1741,7 +1728,7 @@ Uint8 *MdcMakeFLT32(Uint8 *cbuf, FILEINFO *fi, Uint32 img)
      pixval = MdcGetDoublePixel(pixel,id->type);
      newval = (float) (scale * (pixval - smin));
      if (DO_QUANT_CALIBR) newval += id->rescale_intercept;
-     buf[i] = newval; 
+     buf[i] = newval;
   }
 
   id->rescaled = MDC_YES;
@@ -1749,7 +1736,7 @@ Uint8 *MdcMakeFLT32(Uint8 *cbuf, FILEINFO *fi, Uint32 img)
     id->rescaled_fctr = 1.; /* got the real quantified values this time! */
     id->rescaled_slope= 1.;
     id->rescaled_intercept = 0.;
-    id->rescaled_max  = max; 
+    id->rescaled_max  = max;
     id->rescaled_min  = min;
   }else if (DO_CAST == MDC_NO) {
       id->rescaled_fctr = 1.;
@@ -1764,12 +1751,12 @@ Uint8 *MdcMakeFLT32(Uint8 *cbuf, FILEINFO *fi, Uint32 img)
   return((Uint8 *)buf);
 
 }
-  
+
 
 
 /* converts from FLT64 to FLT32                              */
 /* or in case of quantification all other types into a FLT32 */
-Uint8 *MdcGetImgFLT32(FILEINFO *fi, Uint32 img) 
+Uint8 *MdcGetImgFLT32(FILEINFO *fi, Uint32 img)
 {
   IMG_DATA *id = &fi->image[img];
   Uint32 bytes  = id->width * id->height * MdcType2Bytes(FLT32);
@@ -1785,7 +1772,7 @@ Uint8 *MdcGetImgFLT32(FILEINFO *fi, Uint32 img)
 
 }
 
-Uint8 *MdcMakeImgSwapped(Uint8 *cbuf, FILEINFO *fi, Uint32 img, 
+Uint8 *MdcMakeImgSwapped(Uint8 *cbuf, FILEINFO *fi, Uint32 img,
                          Uint32 width, Uint32 height, int type)
 {
   IMG_DATA *id = &fi->image[img];
@@ -1808,7 +1795,7 @@ Uint8 *MdcMakeImgSwapped(Uint8 *cbuf, FILEINFO *fi, Uint32 img,
     MdcForceSwap(pixel,pixbytes);
   }
 
-  return(cbuf); 
+  return(cbuf);
 
 }
 
@@ -1858,7 +1845,7 @@ int MdcUnpackBIT12(FILEINFO *fi, Uint32 img)
    MdcFree(id->buf); id->buf = (Uint8 *)buf16;
 
    id->bits = 12; id->type = BIT16_U;
- 
+
    return(MDC_YES);
 
 }
@@ -1880,11 +1867,11 @@ Uint32 MdcHashSDBM(unsigned char *str)
 {
   unsigned long hash = 0;
   int c;
-    
+
   while ((c = *str++)) {
     hash = c + (hash << 6) + (hash << 16) - hash;
   }
- 
+
   return hash;
 
 }
