@@ -4,7 +4,7 @@
  * UTIL C-source: Medical Image Conversion Utility                         *
  *                                                                         *
  * purpose      : Nice output, edit strings & print defaults               *
- *                                                                         * 
+ *                                                                         *
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * Functions    : MdcPrintLine()          - Print a full or half line      *
@@ -60,11 +60,11 @@
  *                MdcAddCompressionExt()  - Add  compression extension     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-fancy.c,v 1.62 2011/12/27 00:46:06 enlf Exp $
+/* $Id$
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2019 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -143,7 +143,7 @@ void MdcPrintBoxLine(char c, int t)
   MdcPrntScrn("\t\t#");
   for (i=-1;i<=t;i++) MdcPrntScrn("%c",c);
   MdcPrntScrn("#\n");
-  
+
 }
 
 void MdcPrintYesNo(int value )
@@ -155,14 +155,13 @@ void MdcPrintYesNo(int value )
   }
 }
 
-void MdcPrintImageLayout(FILEINFO *fi, Uint32 gen, Uint32 img
-                                     , Uint32 *abs, int repeat)
+void MdcPrintImageLayout(FILEINFO *fi, Uint32 gen, Uint32 img, int repeat)
 {
   IMG_DATA *id;
   Uint32 i;
 
   MdcPrintLine('-',MDC_FULL_LENGTH);
-  MdcPrntScrn("\t\t\tSUMMARY OF IMAGE LAYOUT\n");
+  MdcPrntScrn("\t\t\tSUMMARY OF IMAGE FILE LAYOUT\n");
   MdcPrintLine('-',MDC_FULL_LENGTH);
 
   if ((gen==0) && (img==0))  MdcPrintBoxLine('-',MDC_BOX_SIZE);
@@ -174,15 +173,17 @@ void MdcPrintImageLayout(FILEINFO *fi, Uint32 gen, Uint32 img
   for (i=0; i<fi->number; i++) {
      id = &fi->image[i];
      if ( ((i==0) && (img>0)) || (repeat) ) {
-       if ( ! ((i==0) && (gen>0)) )MdcPrintBoxLine('-',MDC_BOX_SIZE); 
+       if ( ! ((i==0) && (gen>0)) )MdcPrintBoxLine('-',MDC_BOX_SIZE);
        MdcPrntScrn("\t\t| Image   Header   |  \t(%u)\n",img);
        MdcPrintBoxLine('-',MDC_BOX_SIZE);
      }
      MdcPrntScrn("\t\t! Image #%-4u ",i+1);
-     if (fi->endian != MDC_HOST_ENDIAN) MdcPrntScrn("swap !"); 
+     if (fi->endian != MDC_HOST_ENDIAN) MdcPrntScrn("swap !");
      else MdcPrntScrn("     !");
      MdcPrntScrn("\t(%ux%ux%u)",id->width,id->height,MdcType2Bytes(id->type));
-     if (abs!=NULL) if (abs[i] > 0) MdcPrntScrn("\tOFFSET: %u",abs[i]);
+     if (id->load_location != 0) {
+       MdcPrntScrn("\tOFFSET: %u",(Uint32)id->load_location);
+     }
      MdcPrntScrn("\n");
 
   }
@@ -191,18 +192,18 @@ void MdcPrintImageLayout(FILEINFO *fi, Uint32 gen, Uint32 img
 
 int MdcPrintValue(FILE *fp, Uint8 *pvalue, Uint16 type)
 {
-  
+
   switch (type) {
    case BIT8_S:
     {
       Int8 *val = (Int8 *) pvalue;
-      fprintf(fp,"%hd",val[0]);
+      fprintf(fp,"%hhd",val[0]);
     }
     break;
    case BIT8_U:
     {
       Uint8 *val = (Uint8 *) pvalue;
-      fprintf(fp,"%hu",val[0]);
+      fprintf(fp,"%hhu",val[0]);
     }
     break;
    case BIT16_S:
@@ -229,7 +230,6 @@ int MdcPrintValue(FILE *fp, Uint8 *pvalue, Uint16 type)
       fprintf(fp,"%d",val[0]);
     }
     break;
-#ifdef HAVE_8BYTE_INT
    case BIT64_S:
     {
       Int64 *val = (Int64 *) pvalue;
@@ -242,7 +242,6 @@ int MdcPrintValue(FILE *fp, Uint8 *pvalue, Uint16 type)
       fprintf(fp,"%lu",val[0]);
     }
     break;
-#endif
    case FLT32:
     {
       float *val = (float *) pvalue;
@@ -261,7 +260,7 @@ int MdcPrintValue(FILE *fp, Uint8 *pvalue, Uint16 type)
 }
 
 void MdcLowStr(char *str)
-{ 
+{
   char *c;
 
   c=str;
@@ -286,26 +285,26 @@ void MdcKillSpaces(char string[]) /* kill first and last spaces */
 
   length = strlen(string);
 
-  if (length > 0) { 
+  if (length > 0) {
     /* kill the first spaces */
-    while (isspace((int)string[i])) { 
+    while (isspace((int)string[i])) {
          if (i < length) {
-           i+=1; shift+=1; 
+           i+=1; shift+=1;
          }else break;
     }
     if (shift) for (i=0; i<=length; i++) string[i] = string[i+shift];
 
     /* kill the last  spaces */
     length = strlen(string);
-    if (length > 0) { 
+    if (length > 0) {
       i = length - 1;
-      while (isspace((int)string[i])) { 
+      while (isspace((int)string[i])) {
            if (i > 0 ) {
              string[i] = '\0'; i-=1;
            }else break;
       }
     }
-  } 
+  }
 }
 
 void MdcRemoveAllSpaces(char string[]) /* remove all spaces */
@@ -334,7 +333,7 @@ void MdcRemoveEnter(char string[])
   p = strchr(string,'\r'); if (p != NULL) p[0] = '\0';
   p = strchr(string,'\n'); if (p != NULL) p[0] = '\0';
 
-} 
+}
 
 void MdcGetStrLine(char string[], int maxchars, FILE *fp)
 {
@@ -345,7 +344,7 @@ void MdcGetStrLine(char string[], int maxchars, FILE *fp)
 }
 
 void MdcGetStrInput(char string[], int maxchars)
-{ 
+{
   MdcGetStrLine(string,maxchars,stdin);
 }
 
@@ -377,13 +376,13 @@ int MdcGetSubStr(char *dest, char *src, int dmax, char sep, int n)
 
   strncpy(dest,&src[b],sublength);
 
-  dest[sublength] = '\0'; 
+  dest[sublength] = '\0';
 
   MdcKillSpaces(dest);
 
   return(MDC_YES);
 }
- 
+
 void MdcGetSafeString(char *dest, char *src, Uint32 length, Uint32 maximum)
 {
    Uint32 MAX = maximum - 1; /* let's be really safe */
@@ -415,7 +414,7 @@ int MdcPutDefault(char string[]) /* 1=default  or 0=no default */
 
 int MdcGetRange(const char *item, Uint32 *from, Uint32 *to, Uint32 *step)
 {
-  Uint32 a1, a2, t;
+  Uint32 a1=0, a2=0, t=1;
 
   /* read range values */
   if (strchr(item,':') != 0 ) {
@@ -428,11 +427,12 @@ int MdcGetRange(const char *item, Uint32 *from, Uint32 *to, Uint32 *step)
     /* range v2 */
     sscanf(item,"%u-%u",&a1,&a2); t=1;
   }else{
-    /* single */
-    sscanf(item,"%u",&a1); a2=a1;   t=1;
+    /* no range specified */
+    return(MDC_BAD_CODE);
   }
 
-  /* some sanity checks */ 
+  /* some sanity checks */
+  if (a1 == a2) return(MDC_BAD_CODE);
   if (t == 0) t = 1;
 
   *from = a1; *to = a2; *step = t;
@@ -489,12 +489,12 @@ char *MdcHandleEcatList(char *list, Uint32 **dims, Uint32 max)
 
          /* include image number */
          if ((*dims)[i] == MDC_NO) {
-           (*dims)[i] = MDC_YES; 
+           (*dims)[i] = MDC_YES;
            (*dims)[0] += 1;
          }
 
          if ((REVERSED == MDC_YES) && (i < t)) break;
-          
+
          /* set next image number in range */
          i = (REVERSED == MDC_YES) ? (i-t) : (i+t);
 
@@ -509,7 +509,7 @@ char *MdcHandleEcatList(char *list, Uint32 **dims, Uint32 max)
 
        ITEM_FOUND = MDC_NO;
 
-     } 
+     }
   }
 
   return(NULL);
@@ -526,7 +526,7 @@ char *MdcHandleNormList(char *list,Uint32 **inrs,Uint32 *it
   length = strlen(list);
 
   /* <enter> = default: all */
-  if (MdcUseDefault(list)) { 
+  if (MdcUseDefault(list)) {
     (*inrs)[1] = 0; *it = 2; return(NULL);
   }
 
@@ -584,7 +584,7 @@ char *MdcHandleNormList(char *list,Uint32 **inrs,Uint32 *it
          }else{
            if (i > a2) HANDLE = MDC_NO;
          }
-         
+
        }while (HANDLE == MDC_YES);
 
        ITEM_FOUND = MDC_NO;
@@ -597,7 +597,7 @@ char *MdcHandleNormList(char *list,Uint32 **inrs,Uint32 *it
 
 }
 
-char *MdcHandlePixelList(char *list, Uint32 **cols, Uint32 **rows, 
+char *MdcHandlePixelList(char *list, Uint32 **cols, Uint32 **rows,
                          Uint32 *it, Uint32 *bt)
 {
   int ITEM_FOUND=MDC_NO;
@@ -632,7 +632,7 @@ char *MdcHandlePixelList(char *list, Uint32 **cols, Uint32 **rows,
        col=item;
        row=strchr(item,',');
 
-       if ( row == NULL) return("Wrong input!"); 
+       if ( row == NULL) return("Wrong input!");
 
        *row = '\0'; row += 1;
 
@@ -644,18 +644,18 @@ char *MdcHandlePixelList(char *list, Uint32 **cols, Uint32 **rows,
          c_from = 0; c_to = 0;
        }else if (c_from > c_to) {
          tmp = c_from; c_from = c_to; c_to = tmp;
-       } 
+       }
 
        if (MdcGetRange(row,&r_from,&r_to,&r_step) != MDC_OK)
-         return("Error reading row range"); 
+         return("Error reading row range");
 
        /* some checks */
        if (r_from == 0 || r_to == 0) {
          r_from = 0; r_to = 0;
        }else if (r_from > r_to) {
          tmp = r_from; r_from = r_to; r_to = tmp;
-       } 
-       
+       }
+
        for (r=r_from; r<=r_to; r+=r_step)
        for (c=c_from; c<=c_to; c+=c_step) {
           (*cols)[*it] = c;
@@ -684,7 +684,7 @@ char *MdcHandlePixelList(char *list, Uint32 **cols, Uint32 **rows,
 }
 
 char *MdcGetStrAcquisition(int acq_type)
-{ 
+{
   switch (acq_type) {
     case MDC_ACQUISITION_STATIC : return("Static");
                                        break;
@@ -698,7 +698,7 @@ char *MdcGetStrAcquisition(int acq_type)
                                        break;
     default                     : return("Unknown");
   }
-} 
+}
 
 char *MdcGetStrRawConv(int rawconv)
 {
@@ -757,7 +757,7 @@ char *MdcGetStrColorMap(int map)
    case MDC_MAP_GRAY    : return("gray normal"); break;
    case MDC_MAP_INVERTED: return("gray invers"); break;
    case MDC_MAP_RAINBOW : return("rainbow");     break;
-   case MDC_MAP_COMBINED: return("combined");    break; 
+   case MDC_MAP_COMBINED: return("combined");    break;
    case MDC_MAP_HOTMETAL: return("hotmetal");    break;
    case MDC_MAP_LOADED  : return("loaded LUT");  break;
    default              : return("Unknown");
@@ -795,64 +795,64 @@ char *MdcGetStrPatSlOrient(int patient_slice_orient)
 
    case MDC_SUPINE_HEADFIRST_TRANSAXIAL:
     strcpy(mdcbufr,"Supine;HeadFirst;Transverse");  break;
-   case MDC_SUPINE_HEADFIRST_SAGITTAL   : 
+   case MDC_SUPINE_HEADFIRST_SAGITTAL   :
     strcpy(mdcbufr,"Supine;HeadFirst;Sagittal");    break;
-   case MDC_SUPINE_HEADFIRST_CORONAL    : 
+   case MDC_SUPINE_HEADFIRST_CORONAL    :
     strcpy(mdcbufr,"Supine;HeadFirst;Coronal");     break;
-   case MDC_SUPINE_FEETFIRST_TRANSAXIAL: 
+   case MDC_SUPINE_FEETFIRST_TRANSAXIAL:
     strcpy(mdcbufr,"Supine;FeetFirst;Transverse");  break;
-   case MDC_SUPINE_FEETFIRST_SAGITTAL   : 
+   case MDC_SUPINE_FEETFIRST_SAGITTAL   :
     strcpy(mdcbufr,"Supine;FeetFirst;Sagittal");    break;
-   case MDC_SUPINE_FEETFIRST_CORONAL    : 
+   case MDC_SUPINE_FEETFIRST_CORONAL    :
     strcpy(mdcbufr,"Supine;FeetFirst;Coronal");     break;
-   case MDC_PRONE_HEADFIRST_TRANSAXIAL : 
+   case MDC_PRONE_HEADFIRST_TRANSAXIAL :
     strcpy(mdcbufr,"Prone;HeadFirst;Transverse");   break;
-   case MDC_PRONE_HEADFIRST_SAGITTAL    : 
+   case MDC_PRONE_HEADFIRST_SAGITTAL    :
     strcpy(mdcbufr,"Prone;HeadFirst;Sagittal");     break;
-   case MDC_PRONE_HEADFIRST_CORONAL     : 
+   case MDC_PRONE_HEADFIRST_CORONAL     :
     strcpy(mdcbufr,"Prone;HeadFirst;Coronal");      break;
-   case MDC_PRONE_FEETFIRST_TRANSAXIAL : 
+   case MDC_PRONE_FEETFIRST_TRANSAXIAL :
     strcpy(mdcbufr,"Prone;FeetFirst;Transverse");   break;
-   case MDC_PRONE_FEETFIRST_SAGITTAL    : 
+   case MDC_PRONE_FEETFIRST_SAGITTAL    :
     strcpy(mdcbufr,"Prone;FeetFirst;Sagittal");     break;
    case MDC_PRONE_FEETFIRST_CORONAL     :
     strcpy(mdcbufr,"Prone;FeetFirst;Coronal");      break;
    case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL:
     strcpy(mdcbufr,"DecubitusRight;HeadFirst;Transverse"); break;
-   case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL   : 
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL   :
     strcpy(mdcbufr,"DecubitusRight;HeadFirst;Sagittal");   break;
-   case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL    : 
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL    :
     strcpy(mdcbufr,"DecubitusRight;HeadFirst;Coronal");    break;
-   case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL: 
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL:
     strcpy(mdcbufr,"DecubitusRight;FeetFirst;Transverse"); break;
-   case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL   : 
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL   :
     strcpy(mdcbufr,"DecubitusRight;FeetFirst;Sagittal");   break;
-   case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL    : 
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL    :
     strcpy(mdcbufr,"DecubitusRight;FeetFirst;Coronal");    break;
-   case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL : 
+   case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL :
     strcpy(mdcbufr,"DecubitusLeft;HeadFirst;Transverse");  break;
-   case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL    : 
+   case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL    :
     strcpy(mdcbufr,"DecubitusLeft;HeadFirst;Sagittal");    break;
-   case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL     : 
+   case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL     :
     strcpy(mdcbufr,"DecubitusLeft;HeadFirst;Coronal");     break;
-   case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL : 
+   case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL :
     strcpy(mdcbufr,"DecubitusLeft;FeetFirst;Transverse");  break;
-   case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL    : 
+   case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL    :
     strcpy(mdcbufr,"DecubitusLeft;FeetFirst;Sagittal");    break;
    case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL     :
     strcpy(mdcbufr,"DecubitusLeft;FeetFirst;Coronal");     break;
-   default                              : 
+   default                              :
     strcpy(mdcbufr,"Unknown");
 
   }
-  
+
   return(mdcbufr);
-} 
+}
 
 char *MdcGetStrPatPos(int patient_slice_orient)
 {
   switch (patient_slice_orient) {
-    case MDC_SUPINE_HEADFIRST_TRANSAXIAL: 
+    case MDC_SUPINE_HEADFIRST_TRANSAXIAL:
     case MDC_SUPINE_HEADFIRST_SAGITTAL   :
     case MDC_SUPINE_HEADFIRST_CORONAL    :
         strcpy(mdcbufr,"HFS"); break;
@@ -868,7 +868,7 @@ char *MdcGetStrPatPos(int patient_slice_orient)
     case MDC_PRONE_FEETFIRST_SAGITTAL    :
     case MDC_PRONE_FEETFIRST_CORONAL     :
         strcpy(mdcbufr,"FFP"); break;
-    case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL: 
+    case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL:
     case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL   :
     case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL    :
         strcpy(mdcbufr,"HFDR"); break;
@@ -955,7 +955,7 @@ char *MdcGetStrSliceOrient(int patient_slice_orient)
      case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL:
      case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL :
       strcpy(mdcbufr,"Coronal");   break;
-     default                              : 
+     default                              :
       strcpy(mdcbufr,"unknown");
   }
 
@@ -963,7 +963,7 @@ char *MdcGetStrSliceOrient(int patient_slice_orient)
 }
 
 char *MdcGetStrRotation(int rotation)
-{ 
+{
   switch (rotation) {
     case MDC_ROTATION_CW: strcpy(mdcbufr,"clockwise");         break;
     case MDC_ROTATION_CC: strcpy(mdcbufr,"counter-clockwise"); break;
@@ -1084,7 +1084,7 @@ int MdcGetIntSliceOrient(int patient_slice_orient)
      case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL :
       slice_orient = MDC_CORONAL;
       break;
-     default                              : 
+     default                              :
       slice_orient = MDC_TRANSAXIAL;
   }
 
@@ -1101,7 +1101,7 @@ const char *MdcGetLibShortVersion(void)
 {
   return(MDC_VERSION);
 }
-  
+
 /* returns the new stringsize value or 0 in case of error to add */
 Uint32 MdcCheckStrSize(char *str_to_add, Uint32 current_size, Uint32 max)
 {
@@ -1118,7 +1118,7 @@ Uint32 MdcCheckStrSize(char *str_to_add, Uint32 current_size, Uint32 max)
   }
 
   return(new_size);
-} 
+}
 
 /* print to global `mdcbufr' array */
 int MdcMakeScanInfoStr(FILEINFO *fi)
@@ -1213,10 +1213,10 @@ Short Patient/Scan Information\n\
 
 }
 
-int MdcIsDigit(char c) 
+int MdcIsDigit(char c)
 {
   if (c >= '0' && c <= '9') return MDC_YES;
-  
+
   return(MDC_NO);
 }
 
@@ -1297,5 +1297,5 @@ void MdcAddCompressionExt(int ctype, char *fname)
      case MDC_COMPRESS: strcat(fname,".Z");  break;
 
      case MDC_GZIP    : strcat(fname,".gz"); break;
-   } 
+   }
 }
