@@ -9,7 +9,7 @@
  *                                                                         *
  * Functions    : MdcOpenFile()         - Open file                        *
  *                MdcReadFile()         - Read file                        *
- *                MdcWriteFile()        - Write file                       * 
+ *                MdcWriteFile()        - Write file                       *
  *                MdcLoadFile()         - Load file                        *
  *                MdcSaveFile()         - Save file                        *
  *                MdcLoadPlane()        - Load one plane                   *
@@ -27,9 +27,9 @@
  *                MdcGetFname()         - Get filename                     *
  *                MdcSetExt()           - Set filename extension           *
  *                MdcNewExt()           - Create filename extension        *
- *                MdcPrefix()           - Create filename prefix           * 
+ *                MdcPrefix()           - Create filename prefix           *
  *                MdcGetPrefixNr()      - Get proper filename prefix       *
- *                MdcGetLastPathDelim() - Get pointer last path delimiter  * 
+ *                MdcGetLastPathDelim() - Get pointer last path delimiter  *
  *                MdcMySplitPath()      - Split path from filename         *
  *                MdcMyMergePath()      - Merge path to filename           *
  *                MdcNewName()          - Create new filename              *
@@ -46,11 +46,11 @@
  *                MdcGetHeartRate()     - Get heart rate from gated data   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-files.c,v 1.114 2011/12/27 00:46:06 enlf Exp $ 
+/* $Id$
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2019 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -65,7 +65,7 @@
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    59 Place - Suite 330, Boston, MA 02111-1307, USA.  */
- 
+
 /****************************************************************************
                               H E A D E R S
 ****************************************************************************/
@@ -107,8 +107,8 @@ int MdcOpenFile(FILEINFO *fi, const char *path)
         /* no longer quit, because NIFTI */
         /* can read .gz files directly   */
         /* return(MDC_BAD_OPEN); */
-       
-        /* prevent unwanted unlink later */ 
+
+        /* prevent unwanted unlink later */
         ctype = MDC_NO;
       }
     }
@@ -130,9 +130,9 @@ int MdcOpenFile(FILEINFO *fi, const char *path)
   if (ctype != MDC_NO) unlink(path);
 
   MdcSplitPath(fi->ipath,fi->idir,fi->ifname);
- 
+
   return(MDC_OK);
-  
+
 }
 
 int MdcReadFile(FILEINFO *fi, int filenr, char *(*ReadFunc)(FILEINFO *fi))
@@ -181,7 +181,7 @@ int MdcReadFile(FILEINFO *fi, int filenr, char *(*ReadFunc)(FILEINFO *fi))
 
     case MDC_FRMT_ECAT7: msg=MdcReadECAT7(fi); break;
 #endif
-#if MDC_INCLUDE_INTF 
+#if MDC_INCLUDE_INTF
     case MDC_FRMT_INTF: msg=MdcReadINTF(fi); break;
 #endif
 #if MDC_INCLUDE_ANLZ
@@ -228,7 +228,7 @@ int MdcReadFile(FILEINFO *fi, int filenr, char *(*ReadFunc)(FILEINFO *fi))
   /* set the proper color map */
   if (fi->map == MDC_MAP_GRAY) {
     /* gray scale images, set selected colormap  */
-    if (MDC_COLOR_MAP < MDC_MAP_GRAY) MDC_COLOR_MAP = MDC_MAP_GRAY; 
+    if (MDC_COLOR_MAP < MDC_MAP_GRAY) MDC_COLOR_MAP = MDC_MAP_GRAY;
     fi->map = MDC_COLOR_MAP;
   }else{
     /* colored images, preserve map */
@@ -274,7 +274,7 @@ int MdcReadFile(FILEINFO *fi, int filenr, char *(*ReadFunc)(FILEINFO *fi))
   }
 
   return(MDC_OK);
- 
+
 }
 
 int MdcWriteFile(FILEINFO *fi, int format, int prefixnr, char *(*WriteFunc)())
@@ -294,14 +294,14 @@ int MdcWriteFile(FILEINFO *fi, int format, int prefixnr, char *(*WriteFunc)())
   INTERNAL_ENDIAN = MDC_FILE_ENDIAN;
 
   switch (format) {
-    case MDC_FRMT_RAW  : fi->rawconv = MDC_FRMT_RAW; 
+    case MDC_FRMT_RAW  : fi->rawconv = MDC_FRMT_RAW;
                          msg=MdcWriteRAW(fi);
                          break;
     case MDC_FRMT_ASCII: fi->rawconv = MDC_FRMT_ASCII;
-                         msg=MdcWriteRAW(fi);      
+                         msg=MdcWriteRAW(fi);
                          break;
 #if MDC_INCLUDE_ACR
-    case MDC_FRMT_ACR  : msg=MdcWriteACR(fi);  break; 
+    case MDC_FRMT_ACR  : msg=MdcWriteACR(fi);  break;
 #endif
 #if MDC_INCLUDE_GIF
     case MDC_FRMT_GIF  : msg=MdcWriteGIF(fi);  break;
@@ -340,7 +340,7 @@ int MdcWriteFile(FILEINFO *fi, int format, int prefixnr, char *(*WriteFunc)())
         MdcPrntWarn("Writing: Unsupported format");
         return(MDC_BAD_FILE);
       }
-  } 
+  }
 
  /* restore internal file endian - global var issue */
   MDC_FILE_ENDIAN = INTERNAL_ENDIAN;
@@ -353,7 +353,7 @@ int MdcWriteFile(FILEINFO *fi, int format, int prefixnr, char *(*WriteFunc)())
   }
 
   return(MDC_OK);
- 
+
 }
 
 int MdcLoadFile(FILEINFO *fi)
@@ -385,7 +385,7 @@ int MdcLoadFile(FILEINFO *fi)
 
     case MDC_FRMT_ECAT7: msg=MdcReadECAT7(fi); break;
 #endif
-#if MDC_INCLUDE_INTF 
+#if MDC_INCLUDE_INTF
     case MDC_FRMT_INTF: msg=MdcReadINTF(fi); break;
 #endif
 #if MDC_INCLUDE_ANLZ
@@ -432,14 +432,14 @@ int MdcSaveFile(FILEINFO *fi, int format, int prefixnr)
   INTERNAL_ENDIAN = MDC_FILE_ENDIAN;
 
   switch (format) {
-    case MDC_FRMT_RAW  : fi->rawconv = MDC_FRMT_RAW; 
+    case MDC_FRMT_RAW  : fi->rawconv = MDC_FRMT_RAW;
                          msg=MdcWriteRAW(fi);
                          break;
     case MDC_FRMT_ASCII: fi->rawconv = MDC_FRMT_ASCII;
-                         msg=MdcWriteRAW(fi);      
+                         msg=MdcWriteRAW(fi);
                          break;
 #if MDC_INCLUDE_ACR
-    case MDC_FRMT_ACR  : msg=MdcWriteACR(fi);  break; 
+    case MDC_FRMT_ACR  : msg=MdcWriteACR(fi);  break;
 #endif
 #if MDC_INCLUDE_GIF
     case MDC_FRMT_GIF  : msg=MdcWriteGIF(fi);  break;
@@ -475,7 +475,7 @@ int MdcSaveFile(FILEINFO *fi, int format, int prefixnr)
       MdcPrntWarn("Writing: Unsupported format");
       return(MDC_BAD_FILE);
 
-  } 
+  }
 
  /* restore internal file endian - global var issue */
   MDC_FILE_ENDIAN = INTERNAL_ENDIAN;
@@ -503,7 +503,7 @@ int MdcLoadPlane(FILEINFO *fi, Uint32 img)
   /* check the format */
   if (fi->iformat == MDC_FRMT_NONE) {
     MdcPrntWarn("Loading plane %d: unsupported format",img);
-    return(MDC_BAD_CODE); 
+    return(MDC_BAD_CODE);
   }
 
   /* check for loaded planes */
@@ -529,7 +529,7 @@ int MdcLoadPlane(FILEINFO *fi, Uint32 img)
 
     case MDC_FRMT_ECAT7: /* msg=MdcLoadPlaneECAT7(fi, img); */ break;
 #endif
-#if MDC_INCLUDE_INTF 
+#if MDC_INCLUDE_INTF
     case MDC_FRMT_INTF: /* msg=MdcLoadPlaneINTF(fi, img); */ break;
 #endif
 #if MDC_INCLUDE_ANLZ
@@ -599,7 +599,7 @@ int MdcDecompressFile(const char *path)
 
     /* no gunzip? restore orig path */
     *ext = '.';
-    
+
     return(MDC_BAD_CODE);
   }
 
@@ -617,7 +617,7 @@ void MdcStringCopy(char *s1, char *s2, Uint32 length)
     s1[MDC_MAXSTR-1] = '\0';
   }
 }
- 
+
 
 int MdcFileSize(FILE *fp)
 {
@@ -653,12 +653,12 @@ int MdcKeepFile(const char *fname)
   return(MdcFileExists(fname));
 }
 
-int MdcGetFrmt(FILEINFO *fi) 
+int MdcGetFrmt(FILEINFO *fi)
 {
   int i, format=MDC_FRMT_NONE;
 
   if (MDC_FILE_STDIN == MDC_YES && MDC_FRMT_INPUT != MDC_FRMT_NONE) {
-    fi->iformat = MDC_FRMT_INPUT; return(MDC_FRMT_INPUT); 
+    fi->iformat = MDC_FRMT_INPUT; return(MDC_FRMT_INPUT);
   }
 
   if (MDC_INTERACTIVE) { fi->iformat = MDC_FRMT_RAW; return(MDC_FRMT_RAW); }
@@ -667,7 +667,7 @@ int MdcGetFrmt(FILEINFO *fi)
 
     /* MARK: checks reversed; NIFTI must come before ANLZ */
     /* otherwise MdcReadANLZ() would handle NIFTI files   */
-   
+
     switch (i) {
 
 #if MDC_INCLUDE_ACR
@@ -677,7 +677,7 @@ int MdcGetFrmt(FILEINFO *fi)
      case MDC_FRMT_GIF:   format = MdcCheckGIF(fi);  break;
 #endif
 #if MDC_INCLUDE_INW
-     case MDC_FRMT_INW:   format = MdcCheckINW(fi);  break; 
+     case MDC_FRMT_INW:   format = MdcCheckINW(fi);  break;
 #endif
 #if MDC_INCLUDE_INTF
      case MDC_FRMT_INTF:  format = MdcCheckINTF(fi); break;
@@ -704,7 +704,7 @@ int MdcGetFrmt(FILEINFO *fi)
 #endif
     }
 
-    fseek(fi->ifp,0,SEEK_SET); 
+    fseek(fi->ifp,0,SEEK_SET);
 
     if ( format != MDC_FRMT_NONE ) break;
 
@@ -732,7 +732,7 @@ Uint8 *MdcGetImgBuffer(Uint32 bytes)
 char *MdcHandleTruncated(FILEINFO *fi, Uint32 images, int remap)
 {
    Uint32 i;
-  
+
    if (images == 0) images = 1;
    if ((remap == MDC_YES) && (images < fi->number)) {
      if (!MdcGetStructID(fi,images)) {
@@ -773,7 +773,7 @@ int MdcWriteLine(IMG_DATA *id, Uint8 *buf, int type, FILE *fp)
      }
      break;
     case BIT16_U:
-     { 
+     {
         Uint16 pix;
 
         memcpy(&pix,pbuf,bytes); MdcSWAP(pix);
@@ -796,7 +796,6 @@ int MdcWriteLine(IMG_DATA *id, Uint8 *buf, int type, FILE *fp)
         fwrite((char *)&pix,1,bytes,fp);
      }
      break;
-#ifdef HAVE_8BYTE_INT
     case BIT64_S:
      {
         Int64 pix;
@@ -813,7 +812,6 @@ int MdcWriteLine(IMG_DATA *id, Uint8 *buf, int type, FILE *fp)
         fwrite((char *)&pix,1,bytes,fp);
      }
      break;
-#endif
     case FLT32:
      {
        float pix;
@@ -834,8 +832,8 @@ int MdcWriteLine(IMG_DATA *id, Uint8 *buf, int type, FILE *fp)
      {
        float  flt;
 
-       memcpy(&flt,pbuf,bytes); 
-       MdcMakeVAXfl(flt); 
+       memcpy(&flt,pbuf,bytes);
+       MdcMakeVAXfl(flt);
        fwrite((char *)&flt,1,bytes,fp);
 
      }
@@ -843,12 +841,12 @@ int MdcWriteLine(IMG_DATA *id, Uint8 *buf, int type, FILE *fp)
 
    }
  }
- 
+
  if (ferror(fp)) return MDC_NO;
 
  return MDC_YES;
 
-} 
+}
 
 /* Put pixel but MdcSWAP if necessary */
 /* on success 1  on error 0 */
@@ -862,7 +860,7 @@ int MdcWriteDoublePixel(double pix, int type, FILE *fp)
      Int8 c = (Int8)pix;
      fwrite((char *)&c,1,bytes,fp);
    }
-   break; 
+   break;
   case BIT8_U:
    {
      Uint8 c = (Uint8)pix;
@@ -883,7 +881,7 @@ int MdcWriteDoublePixel(double pix, int type, FILE *fp)
    break;
   case BIT32_S:
    {
-     Int32 c = (Int32)pix; 
+     Int32 c = (Int32)pix;
      MdcSWAP(c); fwrite((char *)&c,1,bytes,fp);
    }
    break;
@@ -893,7 +891,6 @@ int MdcWriteDoublePixel(double pix, int type, FILE *fp)
      MdcSWAP(c); fwrite((char *)&c,1,bytes,fp);
    }
    break;
-#ifdef HAVE_8BYTE_INT
   case BIT64_S:
    {
      Int64 c = (Int64)pix;
@@ -906,7 +903,6 @@ int MdcWriteDoublePixel(double pix, int type, FILE *fp)
      MdcSWAP(c); fwrite((char *)&c,1,bytes,fp);
    }
    break;
-#endif 
   case FLT32:
    {
      float c = (float)pix;
@@ -921,7 +917,7 @@ int MdcWriteDoublePixel(double pix, int type, FILE *fp)
      fwrite((char *)&flt,1,bytes,fp);
 
    }
-   break; 
+   break;
   case FLT64:
    {
      double c = (double)pix;
@@ -931,7 +927,7 @@ int MdcWriteDoublePixel(double pix, int type, FILE *fp)
  }
 
  if (ferror(fp)) return MDC_NO;
- 
+
  return MDC_YES;
 
 }
@@ -944,7 +940,7 @@ char *MdcGetFname(char path[])
 
   if ( p == NULL ) return(path);
 
-  return(p+1); 
+  return(p+1);
 }
 
 void MdcSetExt(char path[], char *ext)
@@ -953,7 +949,7 @@ void MdcSetExt(char path[], char *ext)
 
   if (path == NULL) return;
 
-  if (ext  == NULL) return;  
+  if (ext  == NULL) return;
 
   p=(char *)strrchr(path,'.');
 
@@ -988,7 +984,7 @@ void MdcNewExt(char dest[], char *src, char *ext)
   }
 
   MdcSetExt(dest,ext);
-} 
+}
 
 /* create a prefix of the form: 000 ...  ... 999,A00................ZZZ
                                   <- normal ->  |  <----- extra ----->
@@ -1005,7 +1001,7 @@ extra  prefixes =                        +
 This construct gives at first numeric prefixes, extended with
 a lot more alphanumeric prefixes before overlap. A directory
 listing will thus show the filenames in sequence of creation. */
-        
+
 void MdcPrefix(int n)
 {
   int t, c1, c2, c3, v1, v2, v3;
@@ -1015,7 +1011,7 @@ void MdcPrefix(int n)
   if (MDC_PREFIX_DISABLED == MDC_YES) {
     strcpy(prefix,""); return;
   }
-    
+
   if (n < 1000) {
     sprintf(cprefix,"m%03d-",n);
   }else{
@@ -1101,7 +1097,7 @@ char *MdcAliasName(FILEINFO *fi, char alias[])
   day   = fi->study_date_day;
   hour  = fi->study_time_hour;
   minute= fi->study_time_minute;
-  second= fi->study_time_second; 
+  second= fi->study_time_second;
 
   switch (fi->iformat) {
     case MDC_FRMT_ACR:
@@ -1123,7 +1119,7 @@ char *MdcAliasName(FILEINFO *fi, char alias[])
                    ,hour,minute,second);
 
       break;
-    default: 
+    default:
       sprintf(alias,"%s+%s+%hd%02hd%02hd+%02hd%02hd%02hd.ext"
                    ,patient,study
                    ,year,month,day
@@ -1189,8 +1185,8 @@ void MdcDefaultName(FILEINFO *fi, int format, char dest[], char *src)
 #if MDC_INCLUDE_NIFTI
    case MDC_FRMT_NIFTI: MdcNewName(dest,src,FrmtExt[MDC_FRMT_NIFTI]);  break;
 #endif
-   default            : MdcNewName(dest,src,FrmtExt[MDC_FRMT_NONE]);   break; 
-  } 
+   default            : MdcNewName(dest,src,FrmtExt[MDC_FRMT_NONE]);   break;
+  }
 
 }
 
@@ -1214,7 +1210,7 @@ void MdcRenameFile(char *name)
   MdcPrntScrn("\n\tOld Filename: %s\n",mdcbufr);
   MdcPrntScrn("\n\tNew Filename: ");
   MdcGetStrLine(mdcbufr,MDC_MAX_PATH-1,stdin);
-  mdcbufr[MDC_MAX_PATH]='\0'; 
+  mdcbufr[MDC_MAX_PATH]='\0';
   MdcRemoveEnter(mdcbufr);
   strcpy(name,mdcbufr);
 
@@ -1238,7 +1234,7 @@ char *MdcGetLastPathDelim(char *path)
 }
 
 
-void MdcMySplitPath(char path[], char **dir, char **fname) 
+void MdcMySplitPath(char path[], char **dir, char **fname)
 {
   char *p=NULL;
 
@@ -1255,7 +1251,7 @@ void MdcMySplitPath(char path[], char **dir, char **fname)
 
 }
 
-void MdcMyMergePath(char path[], char *dir, char **fname) 
+void MdcMyMergePath(char path[], char *dir, char **fname)
                                       /* first '\0' becomes path delim again */
 {
   char *p;
@@ -1277,7 +1273,7 @@ void MdcFillImgPos(FILEINFO *fi, Uint32 nr, Uint32 plane, float translation)
 
   switch (fi->pat_slice_orient) {
 
-   case MDC_SUPINE_HEADFIRST_TRANSAXIAL: 
+   case MDC_SUPINE_HEADFIRST_TRANSAXIAL:
    case MDC_PRONE_HEADFIRST_TRANSAXIAL :
    case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL:
    case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL :
@@ -1370,7 +1366,7 @@ void MdcFillImgPos(FILEINFO *fi, Uint32 nr, Uint32 plane, float translation)
     id->image_pos_pat[1]=+(id->pixel_ysize*(float)id->height);
     id->image_pos_pat[2]=+((id->slice_spacing*(float)(plane+1))+translation);
     break;
-   case MDC_PRONE_FEETFIRST_SAGITTAL    : 
+   case MDC_PRONE_FEETFIRST_SAGITTAL    :
     id->image_pos_pat[0]=-((id->slice_spacing*(float)(plane+1))+translation);
     id->image_pos_pat[1]=+(id->pixel_xsize*(float)id->width);
     id->image_pos_pat[2]=+(id->pixel_ysize*(float)id->height);
@@ -1462,7 +1458,7 @@ void MdcFillImgOrient(FILEINFO *fi, Uint32 nr)
          id->image_orient_dev[0]=+1.0;    id->image_orient_dev[3]=+0.0;
          id->image_orient_dev[1]=-0.0;    id->image_orient_dev[4]=+1.0;
          id->image_orient_dev[2]=+0.0;    id->image_orient_dev[5]=-0.0;
-         break; 
+         break;
 
      case MDC_SUPINE_HEADFIRST_SAGITTAL   :
      case MDC_PRONE_HEADFIRST_SAGITTAL    :
@@ -1472,7 +1468,7 @@ void MdcFillImgOrient(FILEINFO *fi, Uint32 nr)
      case MDC_PRONE_FEETFIRST_SAGITTAL    :
      case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL:
      case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL :
-         id->image_orient_dev[0]=+0.0;    id->image_orient_dev[3]=+0.0; 
+         id->image_orient_dev[0]=+0.0;    id->image_orient_dev[3]=+0.0;
          id->image_orient_dev[1]=+1.0;    id->image_orient_dev[4]=-0.0;
          id->image_orient_dev[2]=-0.0;    id->image_orient_dev[5]=-1.0;
          break;
@@ -1485,13 +1481,13 @@ void MdcFillImgOrient(FILEINFO *fi, Uint32 nr)
      case MDC_PRONE_FEETFIRST_CORONAL     :
      case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL:
      case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL :
-         id->image_orient_dev[0]=+1.0;    id->image_orient_dev[3]=+0.0; 
+         id->image_orient_dev[0]=+1.0;    id->image_orient_dev[3]=+0.0;
          id->image_orient_dev[1]=-0.0;    id->image_orient_dev[4]=-0.0;
          id->image_orient_dev[2]=+0.0;    id->image_orient_dev[5]=-1.0;
          break;
 
-     default                              : { } 
-  } 
+     default                              : { }
+  }
 
   /* according to patient coordinate system */
 
@@ -1581,7 +1577,7 @@ void MdcFillImgOrient(FILEINFO *fi, Uint32 nr)
 
 int MdcGetOrthogonalInt(float f)
 {
-  int i; 
+  int i;
 
   if (f == 0.0) i = 0;
   else if (f == 1.0) i = 1;
@@ -1594,7 +1590,7 @@ int MdcGetOrthogonalInt(float f)
 
 Int8 MdcGetPatSliceOrient(FILEINFO *fi, Uint32 i)
 {
-  IMG_DATA *id = &fi->image[i]; 
+  IMG_DATA *id = &fi->image[i];
   int   i0,i1,i4,i5;
   int   slice_orientation=MDC_UNKNOWN;
   int   patient_orientation=MDC_UNKNOWN;
@@ -1907,7 +1903,7 @@ float MdcGetHeartRate(GATED_DATA *gd, Int16 type)
 {
    float heart_rate = 0.;
 
-   if (gd->study_duration > 0.) { 
+   if (gd->study_duration > 0.) {
      switch (type) {
        case MDC_HEART_RATE_ACQUIRED:
          /* note: [ms] -> [min] */
@@ -1918,7 +1914,7 @@ float MdcGetHeartRate(GATED_DATA *gd, Int16 type)
          heart_rate = (gd->cycles_observed * 60. * 1000.) / gd->study_duration;
          break;
      }
-   } 
+   }
 
    return(heart_rate);
 }
