@@ -12,11 +12,11 @@
  *                MdcWriteNIFTI()           - Write NIFTI file             *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-nifti.c,v 1.30 2011/12/27 00:46:06 enlf Exp $
+/* $Id$
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2019 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -59,7 +59,7 @@
 #include "medcon.h"
 
 /****************************************************************************
-                              D E F I N E S 
+                              D E F I N E S
 *****************************************************************************/
 
 #define MDC_NIFTI_WRITE_QFORM 0  /* 0/1 write qform orientation & location */
@@ -91,7 +91,7 @@ int MdcCheckNIFTI(FILEINFO *fi)
         break;
 #endif
     case 1:  FORMAT = MDC_FRMT_NIFTI; /* NIFTI one file */
-        break; 
+        break;
     case 2:  FORMAT = MDC_FRMT_NIFTI; /* NIFTI two files */
         break;
     default: FORMAT = MDC_FRMT_NONE;  /* unknown */
@@ -109,7 +109,7 @@ const char *MdcReadNIFTI(FILEINFO *fi)
   int swap, dim[8];
   float xyz_fctr, t_fctr;
   Uint32 i, number, f, bytes;
-  IMG_DATA *id=NULL; 
+  IMG_DATA *id=NULL;
   DYNAMIC_DATA *dd=NULL;
 
   if (MDC_FILE_STDIN == MDC_YES)
@@ -160,7 +160,7 @@ const char *MdcReadNIFTI(FILEINFO *fi)
   }
 
   /* copy dim parameters */
-  for (i=0; i<8; i++) { 
+  for (i=0; i<8; i++) {
      fi->dim[i] = nim->dim[i];
      fi->pixdim[i] = nim->pixdim[i];
      if ((i > 0) && (fi->pixdim[i] > 0.)) fi->pixdim[0] = i; /* one-based */
@@ -238,7 +238,7 @@ const char *MdcReadNIFTI(FILEINFO *fi)
   /* fill in IMG_DATA structs */
   bytes = fi->mwidth * fi->mheight * MdcType2Bytes(fi->type);
   pbuf = (Uint8 *)nim->data;
-  
+
   i=0; dim[0]=7;
   for (dim[7]=0; dim[7] < nim->nw; dim[7]++ )                     /* nw */
   for (dim[6]=0; dim[6] < nim->nv; dim[6]++ )                     /* nv */
@@ -248,7 +248,7 @@ const char *MdcReadNIFTI(FILEINFO *fi)
 
      if (MDC_PROGRESS) MdcProgress(MDC_PROGRESS_INCR,1./(float)fi->number,NULL);
 
-     if (i == fi->number) { 
+     if (i == fi->number) {
        nifti_image_free(nim);
        return("NIFTI Internal ERRRO");
      }
@@ -294,8 +294,8 @@ const char *MdcReadNIFTI(FILEINFO *fi)
        dd->time_frame_start    = f * dd->time_frame_duration
                                  + dd->time_frame_delay;
     }
-  } 
- 
+  }
+
   nifti_image_free(nim);
 
   return(NULL);
@@ -328,7 +328,7 @@ const char *MdcWriteNIFTI(FILEINFO *fi)
 
   /* file endian */
   if (MDC_WRITE_ENDIAN != MDC_HOST_ENDIAN)
-    return("NIFTI Writing in different endianess yet unsupported");
+    return("NIFTI Writing in different endianness yet unsupported");
 
   /* get nifti_image struct */
   nim = nifti_simple_init_nim();
@@ -396,7 +396,7 @@ const char *MdcWriteNIFTI(FILEINFO *fi)
                          NULL,NULL,NULL,NULL,NULL,NULL,&nim->qfac);
 
 #endif
-  
+
   /* single file output */
   nim->nifti_type = 1;
 
@@ -407,13 +407,13 @@ const char *MdcWriteNIFTI(FILEINFO *fi)
 
   /* get rid of any extension left, like .img.hdr -> .img remains */
   /* which would result in a misappropriate two file nifti output */
-  pext = strchr(bname,'.'); if (pext != NULL) pext[0]='\0';    
+  pext = strchr(bname,'.'); if (pext != NULL) pext[0]='\0';
 
   if (MDC_FILE_OVERWRITE == MDC_YES) {
     ret = nifti_set_filenames(nim,bname,0,1);
   }else{
     ret = nifti_set_filenames(nim,bname,1,1);
-  } 
+  }
   free(bname);
 
   if (ret < 0) {
@@ -461,14 +461,14 @@ const char *MdcWriteNIFTI(FILEINFO *fi)
       }
     }
   }
- 
+
   /* initialize output file */
   fp = nifti_image_write_hdr_img(nim,2,"wb");
 
   /* keep lowlevel header */
   nhdr = nifti_convert_nim2nhdr(nim);
 
-  /* free nifti image struct */ 
+  /* free nifti image struct */
   nifti_image_free(nim);
 
   if (fp == NULL) return("NIFTI Writing header data failed");
@@ -516,7 +516,7 @@ const char *MdcWriteNIFTI(FILEINFO *fi)
          /* all (or most) types supported */
          buf = id->buf; FREE=MDC_NO;
          type = id->type;
-       } 
+       }
      }
 
      if (buf == NULL) { znzclose(fp); return("NIFTI Bad malloc image buffer"); }
@@ -564,8 +564,8 @@ const char *MdcWriteNIFTI(FILEINFO *fi)
          if (FREE) MdcFree(maxbuf);
 
          maxbuf = rgbbuf; FREE = MDC_YES;
-        
-         size *= 3; /* RGB triplets */ 
+
+         size *= 3; /* RGB triplets */
          if (nifti_write_buffer(fp,(void *)maxbuf,size) != size) {
            if (FREE) MdcFree(maxbuf);
            znzclose(fp); return("NIFTI Writing indexed buffer failed");
@@ -605,5 +605,5 @@ const char *MdcWriteNIFTI(FILEINFO *fi)
   MDC_NORM_OVER_FRAMES = saved_norm_over_frames;
 
   /* finish */
-  return(NULL); 
+  return(NULL);
 }
