@@ -20,7 +20,7 @@
  * Copyright (c) 1991-1997 Silicon Graphics, Inc.                          *
  *                                                                         *
  * Permission to use, copy, modify, distribute, and sell this software and *
- * its documentation for any purpose is hereby granted without fee,        * 
+ * its documentation for any purpose is hereby granted without fee,        *
  * provided that (i) the above copyright notices and this permission notice*
  * appear in all copies of the software and related documentation, and     *
  * (ii) the names of Sam Leffler and Silicon Graphics may not be used in   *
@@ -28,11 +28,11 @@
  * specific, prior written permission of Sam Leffler and Silicon Graphics. *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-qmedian.c,v 1.20 2011/12/27 00:46:06 enlf Exp $
+/* $Id$
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2019 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -70,7 +70,7 @@
 #include "medcon.h"
 
 /****************************************************************************
-                              D E F I N E S 
+                              D E F I N E S
 ****************************************************************************/
 
 /*
@@ -81,7 +81,7 @@
  *  you are at X, moving left to right:
  *
  *                  X     7/16
- *           3/16   5/16  1/16    
+ *           3/16   5/16  1/16
  *
  *  Note that the error goes to four neighbors, not three.  I think this
  *  will probably do better (at least for black and white) than the
@@ -94,7 +94,7 @@
  *  half the error one pixel ahead (e.g. to the right on lines you scan
  *  left to right), and half one pixel straight down.  Again, this is for
  *  black and white;  I've not tried it with color.
- *  -- 
+ *  --
  *                                          Lou Steinberg
  *
  * [2] Color Image Quantization for Frame Buffer Display, Paul Heckbert,
@@ -161,10 +161,10 @@ char *MdcReduceColor(FILEINFO *fi)
   int i;
   Colorbox *box_list, *ptr;
   Uint8 *dest8;
-  char *msg; 
+  char *msg;
 
 
-  if (fi->diff_type == MDC_YES) 
+  if (fi->diff_type == MDC_YES)
     return("Reduce color unsupported for different types");
 
   if (fi->diff_size == MDC_YES)
@@ -308,7 +308,7 @@ char *MdcRgb2Indexed(Uint8 *srcRGB, Uint8 *dest8, Uint32 width, Uint32 height, U
 {
   int i;
   Colorbox *box_list, *ptr;
-  char *msg; 
+  char *msg;
 
   /*
    * STEP 0: initialize some values
@@ -860,7 +860,7 @@ static char *quant_fsdither(Uint8 *srcRGB, Uint8 *dest8)
   if (thisline == NULL) return("Unable to malloc thisline");
   nextline = (short *)malloc(imagewidth * 3 * sizeof (short));
   if (nextline == NULL) {
-    MdcFree(nextline);
+    MdcFree(thisline);
     return("Unable to malloc nextline");
   }
 
@@ -876,10 +876,10 @@ static char *quant_fsdither(Uint8 *srcRGB, Uint8 *dest8)
     lastline = (i == imax);
     inputline = &srcRGB[i*imagewidth*3]; inptr = inputline;
     nextptr = nextline;
-    for (j = 0; j < imagewidth; ++j) {                      
-       *nextptr++ = *inptr++;        
-       *nextptr++ = *inptr++;           
-       *nextptr++ = *inptr++;                          
+    for (j = 0; j < imagewidth; ++j) {
+       *nextptr++ = *inptr++;
+       *nextptr++ = *inptr++;
+       *nextptr++ = *inptr++;
     }
     thisptr = thisline;
     nextptr = nextline;
