@@ -13,11 +13,11 @@
  *                MdcStackFiles()          - Main stack routine            *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-stack.c,v 1.41 2011/12/27 00:46:06 enlf Exp $
+/* $Id$
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2019 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -43,7 +43,7 @@
 #include "medcon.h"
 
 /****************************************************************************
-                              D E F I N E S 
+                              D E F I N E S
 ****************************************************************************/
 
 static FILEINFO infi, outfi;
@@ -123,7 +123,6 @@ char *MdcStackSlices(void)
        MdcCopyFI(ofi,ifi,MDC_NO,MDC_NO);
 
        /* set some specific parameters */
-       MdcSplitPath(ofi->ipath,ofi->idir,ofi->ifname);
        ofi->dim[0] = 3;
        ofi->dim[1] = ifi->dim[1];
        ofi->dim[2] = ifi->dim[2];
@@ -237,7 +236,7 @@ char *MdcStackSlices(void)
       case MDC_SUPINE_HEADFIRST_TRANSAXIAL          :
       case MDC_SUPINE_FEETFIRST_TRANSAXIAL          :
       case MDC_PRONE_HEADFIRST_TRANSAXIAL           :
-      case MDC_PRONE_FEETFIRST_TRANSAXIAL           : 
+      case MDC_PRONE_FEETFIRST_TRANSAXIAL           :
       case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL   :
       case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL   :
       case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL    :
@@ -266,10 +265,20 @@ char *MdcStackSlices(void)
     ofi->image[0].slice_spacing = ofi->image[1].slice_spacing;
   }
 
+  /* apply read options */
+  msg = MdcApplyReadOptions(ofi);
+  if (msg != NULL) {
+    MdcCleanUpFI(ofi);
+    sprintf(mdcbufr,"stack slices : %s",msg); return(mdcbufr);
+  }
+
   /* if requested, reverse slices */
   if (MDC_SORT_REVERSE == MDC_YES) {
     msg = MdcSortReverse(ofi);
-    if (msg != NULL) return(msg); 
+    if (msg != NULL) {
+      MdcCleanUpFI(ofi);
+      sprintf(mdcbufr,"stack slices : %s",msg); return(mdcbufr);
+    }
   }
 
   /* write the file */
@@ -449,7 +458,7 @@ char *MdcStackFrames(void)
       case MDC_SUPINE_HEADFIRST_TRANSAXIAL          :
       case MDC_SUPINE_FEETFIRST_TRANSAXIAL          :
       case MDC_PRONE_HEADFIRST_TRANSAXIAL           :
-      case MDC_PRONE_FEETFIRST_TRANSAXIAL           : 
+      case MDC_PRONE_FEETFIRST_TRANSAXIAL           :
       case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL   :
       case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL   :
       case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL    :
@@ -467,6 +476,13 @@ char *MdcStackFrames(void)
     }
   }
 
+  /* apply read options */
+  msg = MdcApplyReadOptions(ofi);
+  if (msg != NULL) {
+    MdcCleanUpFI(ofi);
+    sprintf(mdcbufr,"stack frames : %s",msg); return(mdcbufr);
+  }
+
   /* write the file */
   if (total[MDC_CONVS] > 0) {
     /* go through conversion formats */
@@ -495,7 +511,7 @@ char *MdcStackFiles(Int8 stack)
   if (MDC_CONVERT != MDC_YES)
     return("In order to stack specify an output format");
 
-  if (mdc_arg_total[MDC_FILES] == 1) 
+  if (mdc_arg_total[MDC_FILES] == 1)
     return("In order to stack at least two files are required");
 
   switch (stack) {
