@@ -23,14 +23,14 @@
  *                XMdcRawPredefSelSaveCallbackOk()  - Raw Predef Save Ok   *
  *                XMdcRawPredefSelSave()            - Raw Predef Save      *
  *                XMdcRawPredefSelOpenCallbackOk()  - Raw Predef Load Ok   *
- *                XMdcRawPredefSelOpen()            - Raw Predef Load      * 
+ *                XMdcRawPredefSelOpen()            - Raw Predef Load      *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xfilesel.c,v 1.37 2011/12/27 00:46:06 enlf Exp $
+/* $Id$
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2019 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -106,28 +106,28 @@ void XMdcFileSelOpenCallbackOk(GtkWidget *w, GtkWidget *fs)
 
 void XMdcFileSelOpen(GtkWidget *widget, guint otype)
 {
- 
+
     OPEN_TYPE = otype;
 
     if (ofilew == NULL) {
 
       /* Create a new file selection widget */
       ofilew = gtk_file_selection_new ("Open File");
-    
+
       gtk_signal_connect(GTK_OBJECT (ofilew), "destroy",
-                         GTK_SIGNAL_FUNC(XMdcMedconQuit), NULL); 
+                         GTK_SIGNAL_FUNC(XMdcMedconQuit), NULL);
       gtk_signal_connect(GTK_OBJECT (ofilew), "delete_event",
                          GTK_SIGNAL_FUNC(XMdcHandlerToHide), NULL);
 
       /* Connect the ok_button to file_ok_sel function */
       gtk_signal_connect_object(
-         GTK_OBJECT(GTK_FILE_SELECTION(ofilew)->ok_button), 
+         GTK_OBJECT(GTK_FILE_SELECTION(ofilew)->ok_button),
          "clicked", GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(ofilew));
       gtk_signal_connect(GTK_OBJECT (GTK_FILE_SELECTION (ofilew)->ok_button),
          "clicked", GTK_SIGNAL_FUNC(XMdcFileSelOpenCallbackOk),ofilew);
 
       /* Connect the cancel_button to hide the widget */
-      gtk_signal_connect_object(GTK_OBJECT 
+      gtk_signal_connect_object(GTK_OBJECT
          (GTK_FILE_SELECTION (ofilew)->cancel_button),
          "clicked", GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(ofilew));
     }
@@ -142,8 +142,8 @@ void XMdcFileSelOpen(GtkWidget *widget, guint otype)
 
     /* Lets set the filename, as if this were a save dialog, and we are giving
       a default filename */
-    gtk_file_selection_set_filename (GTK_FILE_SELECTION(ofilew), 
-				     "<unknown>");
+    gtk_file_selection_set_filename (GTK_FILE_SELECTION(ofilew),
+        "<unknown>");
     XMdcShowWidget(ofilew);
 
     switch (XMDC_FILE_TYPE) {
@@ -165,7 +165,7 @@ void XMdcFileSelOpen(GtkWidget *widget, guint otype)
 void XMdcFileSelSaveCreateFormatMenu(GtkWidget *fs, guint format)
 {
     GtkWidget *menu=NULL;
-    GtkWidget *menuitem; 
+    GtkWidget *menuitem;
     guint item=0, selected=0;
     Uint8 LOOK=MDC_YES;
 
@@ -398,9 +398,9 @@ void XMdcFileSelSaveCreateDefaultName(GtkWidget *fs)
   MdcDefaultName(my.fi,XMDC_WRITE_FRMT,my.fi->ofname,my.fi->ifname);
 
   gtk_file_selection_set_filename(GTK_FILE_SELECTION(fs),my.fi->ofname);
- 
-} 
-  
+
+}
+
 
 void XMdcFileSelSaveCallbackFormatMenu(GtkWidget *fs, guint *selected_format)
 {
@@ -421,7 +421,7 @@ void XMdcFileSelSaveCallbackAlias(GtkObject *fs, char *filename)
 
   MDC_ALIAS_NAME = prev;
 }
-   
+
 void XMdcFileSelSaveCallbackDefault(GtkObject *fs, char *filename)
 {
   MdcDefaultName(my.fi,XMDC_WRITE_FRMT,my.fi->ofname,my.fi->ifname);
@@ -460,7 +460,7 @@ void XMdcFileSelSave(GtkWidget *widget, guint format)
 
    GtkWidget *menu=NULL;
    GtkWidget *active=NULL;
-   guint nr=mitem_nr[format];
+   guint nr;
 
    nr = (format < MDC_MAX_FRMTS) ? mitem_nr[format] : 1;
 
@@ -487,14 +487,14 @@ void XMdcFileSelSave(GtkWidget *widget, guint format)
      gtk_signal_connect_object(
         GTK_OBJECT(GTK_FILE_SELECTION (sfilew)->ok_button),
         "clicked", GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(sfilew));
-     gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION (sfilew)->ok_button), 
+     gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION (sfilew)->ok_button),
         "clicked", GTK_SIGNAL_FUNC(XMdcFileSelSaveCallbackOk), sfilew);
 
      /* Connect the cancel_button to hide the widget, decrease counter */
      gtk_signal_connect_object(
         GTK_OBJECT(GTK_FILE_SELECTION (sfilew)->cancel_button),
         "clicked", GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(sfilew));
-     gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION (sfilew)->cancel_button), 
+     gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION (sfilew)->cancel_button),
         "clicked", GTK_SIGNAL_FUNC(XMdcFileSelSaveCallbackCancel), NULL);
 
      XMdcFileSelSaveCreateFormatMenu(sfilew,format);
@@ -507,26 +507,26 @@ void XMdcFileSelSave(GtkWidget *widget, guint format)
      gtk_widget_show(button);
 
      button = gtk_button_new_with_label("Default Name");
-     gtk_signal_connect_object(GTK_OBJECT(button), "clicked", 
+     gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
         GTK_SIGNAL_FUNC(XMdcFileSelSaveCallbackDefault), GTK_OBJECT(sfilew));
      gtk_box_pack_start(GTK_BOX(GTK_FILE_SELECTION(sfilew)->action_area),
                         button, TRUE, TRUE, 0);
-     gtk_widget_show(button); 
+     gtk_widget_show(button);
 
      default_name = button;
 
    }else{
-   
+
      if (format == MDC_MAX_FRMTS) {
        /* Save: use previous selected format */
        menu = gtk_option_menu_get_menu(GTK_OPTION_MENU(formatmenu));
        active = gtk_menu_get_active(GTK_MENU(menu));
        gtk_menu_item_activate(GTK_MENU_ITEM(active));
 
-     }else{ 
+     }else{
        /* Save As: use given format */
         nr=mitem_nr[format];
- 
+
         gtk_option_menu_set_history(GTK_OPTION_MENU(formatmenu),nr);
         menu = gtk_option_menu_get_menu(GTK_OPTION_MENU(formatmenu));
         gtk_menu_set_active(GTK_MENU(menu),nr);
@@ -551,7 +551,7 @@ void XMdcLutSelOpenCallbackOk(GtkWidget *w, GtkWidget *fs)
    fname = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
 
    XMdcLoadLUT(fname);
- 
+
 }
 
 void XMdcLutSelOpen(GtkWidget *widget, gpointer data)
@@ -589,7 +589,7 @@ void XMdcLutSelOpen(GtkWidget *widget, gpointer data)
        strcat(xmdcstr,MDC_PATH_DELIM_STR);
 
      gtk_file_selection_set_filename(GTK_FILE_SELECTION(olutw),xmdcstr);
-   }else{ 
+   }else{
      /* installation dir */
      gtk_file_selection_set_filename(GTK_FILE_SELECTION(olutw),XMDCLUT);
    }
@@ -654,7 +654,7 @@ void XMdcRawPredefSelSave(GtkWidget *widget, gpointer data)
   }else{
     gtk_file_selection_set_filename(GTK_FILE_SELECTION(spredefw),"predef.rpi");
   }
-   
+
   XMdcShowWidget(spredefw);
 
 }
