@@ -11,11 +11,11 @@
  *                XMdcShowFileInfo()        - Display general file info    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xinfo.c,v 1.66 2011/12/27 00:46:06 enlf Exp $
+/* $Id$
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2019 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -196,7 +196,7 @@ void XMdcImagesInfo(GtkWidget *widget, Uint32 nr)
   sprintf(xmdcstr,"slice start   : %+e [ms] = %s\n"
                  ,id->slice_start,MdcGetStrHHMMSS(id->slice_start));
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
- 
+
   f = MdcSingleImageDuration(my.fi,id->frame_number-1);
   sprintf(xmdcstr,"slice duration: %+e [ms] = %s (auto-filled)\n"
                  ,f,MdcGetStrHHMMSS(f));
@@ -252,7 +252,7 @@ void XMdcImagesInfo(GtkWidget *widget, Uint32 nr)
                                                  ,sd->start_time_hour
                                                  ,sd->start_time_minute
                                                  ,sd->start_time_second);
-    gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1); 
+    gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
   }
 
   gtk_text_thaw(GTK_TEXT(text));
@@ -302,12 +302,12 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
 
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   gtk_widget_set_usize(window,500,500);
-  gtk_window_set_policy(GTK_WINDOW(window), TRUE, TRUE, FALSE); 
+  gtk_window_set_policy(GTK_WINDOW(window), TRUE, TRUE, FALSE);
 
   gtk_signal_connect(GTK_OBJECT(window),"destroy",
                      GTK_SIGNAL_FUNC(gtk_widget_destroy), NULL);
 
-  sprintf(mdcbufr,"FileInfo: %s",my.fi->ifname); 
+  sprintf(mdcbufr,"FileInfo: %s",my.fi->ifname);
   gtk_window_set_title(GTK_WINDOW(window),mdcbufr);
   gtk_container_set_border_width(GTK_CONTAINER(window),0);
 
@@ -354,7 +354,7 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
   gtk_text_insert(GTK_TEXT(text),fixed,&Blue,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"FILE *ifp   : ");
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
-  if (my.fi->ifp == NULL) 
+  if (my.fi->ifp == NULL)
     sprintf(xmdcstr,"<null>\n");
   else
     sprintf(xmdcstr,"%p\n",(void *)my.fi->ifp);
@@ -372,7 +372,7 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
   gtk_text_insert(GTK_TEXT(text),sfixed,NULL,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"opath       : %s\n",my.fi->opath);
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
-  if (my.fi->idir != NULL) 
+  if (my.fi->idir != NULL)
     sprintf(xmdcstr,"idir        : %s\n",my.fi->idir);
   else
     sprintf(xmdcstr,"idir        : <null>\n");
@@ -414,7 +414,7 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
   sprintf(xmdcstr,"diff_scale  : %d (= %s)\n",v,MdcGetStrYesNo(v));
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
 
-  sprintf(xmdcstr,"\nGeneral Image Information\n"); 
+  sprintf(xmdcstr,"\nGeneral Image Information\n");
   gtk_text_insert(GTK_TEXT(text),fixed,&Blue,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"number      : %u\n",my.fi->number);
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
@@ -425,7 +425,7 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
   sprintf(xmdcstr,"bits        : %hu\n",my.fi->bits);
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
   v = (int)my.fi->type;
-  sprintf(xmdcstr,"type        : %hu (= %s)\n",v,MdcGetStrPixelType(v));
+  sprintf(xmdcstr,"type        : %d (= %s)\n",v,MdcGetStrPixelType(v));
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
 
   sprintf(xmdcstr,"dim[0]      : %-5hd (= total in use)\n",my.fi->dim[0]);
@@ -507,7 +507,7 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
 
   sprintf(xmdcstr,"\nStudy Information\n");
-  gtk_text_insert(GTK_TEXT(text),fixed,&Blue,NULL,xmdcstr,-1); 
+  gtk_text_insert(GTK_TEXT(text),fixed,&Blue,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"operator_name    : %s\n",my.fi->operator_name);
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"study_descr      : %s\n",my.fi->study_descr);
@@ -532,11 +532,11 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"dose_time_second : %02d\n",my.fi->dose_time_second);
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
-  sprintf(xmdcstr,"nr_series        : %hd\n",my.fi->nr_series);
+  sprintf(xmdcstr,"nr_series        : %d\n",my.fi->nr_series);
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
-  sprintf(xmdcstr,"nr_acquisition   : %hd\n",my.fi->nr_acquisition);
+  sprintf(xmdcstr,"nr_acquisition   : %d\n",my.fi->nr_acquisition);
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
-  sprintf(xmdcstr,"nr_instance      : %hd\n",my.fi->nr_instance);
+  sprintf(xmdcstr,"nr_instance      : %d\n",my.fi->nr_instance);
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
   v = (int)my.fi->decay_corrected;
   sprintf(xmdcstr,"decay_corrected  : %d (= %s)\n",v,MdcGetStrYesNo(v));
