@@ -18,11 +18,11 @@
  *                XMdcLabelSel()                - Label selection          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xlabels.c,v 1.26 2011/12/27 00:46:06 enlf Exp $
+/* $Id$
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2019 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -98,7 +98,7 @@ void XMdcGetEcatLabelNumbers(Uint32 realnumber, Uint32 *plane, Uint32 *frame,
 }
 
 char *XMdcGetImageLabelIndex(Uint32 nr)
-{ 
+{
    switch (sLabelSelection.CurStyle) {
      case XMDC_LABEL_STYLE_ABS :   sprintf(labelindex,"%u",my.realnumber[nr]+1);
                                    break;
@@ -123,7 +123,7 @@ char *XMdcGetImageLabelTimes(Uint32 nr)
   float duration;
   char s[10], d[10];
 
-  
+
   if (my.fi->dynnr == 0) { labeltimes[0]='\0'; return(labeltimes); }
 
   i = my.realnumber[nr];
@@ -132,7 +132,7 @@ char *XMdcGetImageLabelTimes(Uint32 nr)
   f = id->frame_number;
   duration = MdcSingleImageDuration(my.fi,f-1);
   strncpy(s,MdcGetStrHHMMSS(id->slice_start),10); s[9]='\0';
-  strncpy(d,MdcGetStrHHMMSS(duration),10);        s[9]='\0';
+  strncpy(d,MdcGetStrHHMMSS(duration),10);        d[9]='\0';
 
   sprintf(labeltimes,"%u S=%s D=%s",f,s,d);
 
@@ -143,98 +143,98 @@ char *XMdcGetImageLabelTimes(Uint32 nr)
 
 void XMdcPrintImageLabelIndex(GtkWidget *widget, Uint32 nr)
 {
-	GdkColormap *map = gtk_widget_get_colormap(widget);
-	char *label;
+  GdkColormap *map = gtk_widget_get_colormap(widget);
+  char *label;
 
-	/* first, create a GC to draw on */
-	sLabelSelection.gc = gdk_gc_new(widget->window);
+  /* first, create a GC to draw on */
+  sLabelSelection.gc = gdk_gc_new(widget->window);
 
-	switch (sLabelSelection.CurColor) {
-		case XMDC_LABEL_RED   : sLabelSelection.color = &Red; break;
-		case XMDC_LABEL_GREEN : sLabelSelection.color = &Green; break;
-		case XMDC_LABEL_BLUE  : sLabelSelection.color = &Blue; break;
-		case XMDC_LABEL_YELLOW: sLabelSelection.color = &Yellow; break;
-	} 
+  switch (sLabelSelection.CurColor) {
+    case XMDC_LABEL_RED   : sLabelSelection.color = &Red; break;
+    case XMDC_LABEL_GREEN : sLabelSelection.color = &Green; break;
+    case XMDC_LABEL_BLUE  : sLabelSelection.color = &Blue; break;
+    case XMDC_LABEL_YELLOW: sLabelSelection.color = &Yellow; break;
+  }
 
 
-	/* set the foreground to our color */
-	gdk_colormap_alloc_color(map,sLabelSelection.color, FALSE, TRUE);
-	gdk_gc_set_foreground(sLabelSelection.gc, sLabelSelection.color);
+  /* set the foreground to our color */
+  gdk_colormap_alloc_color(map,sLabelSelection.color, FALSE, TRUE);
+  gdk_gc_set_foreground(sLabelSelection.gc, sLabelSelection.color);
 
-	label=XMdcGetImageLabelIndex(nr);
+  label=XMdcGetImageLabelIndex(nr);
 
-	gdk_draw_string(widget->window, sfixed, sLabelSelection.gc
-                        , 2, (gint)(XMdcScaleH(my.fi->mheight)-2), label);
+  gdk_draw_string(widget->window, sfixed, sLabelSelection.gc
+      , 2, (gint)(XMdcScaleH(my.fi->mheight)-2), label);
 
-	gdk_colormap_free_colors(map,sLabelSelection.color,1);
-	gdk_gc_destroy(sLabelSelection.gc);
+  gdk_colormap_free_colors(map,sLabelSelection.color,1);
+  gdk_gc_destroy(sLabelSelection.gc);
 }
 
 void XMdcPrintImageLabelTimes(GtkWidget *widget, Uint32 nr)
 {
-	GdkColormap *map = gtk_widget_get_colormap(widget);
-	char *label;
+  GdkColormap *map = gtk_widget_get_colormap(widget);
+  char *label;
 
-	/* first, create a GC to draw on */
-	sLabelSelection.gc = gdk_gc_new(widget->window);
+  /* first, create a GC to draw on */
+  sLabelSelection.gc = gdk_gc_new(widget->window);
 
-	switch (sLabelSelection.CurColor) {
-		case XMDC_LABEL_RED   : sLabelSelection.color = &Red; break;
-		case XMDC_LABEL_GREEN : sLabelSelection.color = &Green; break;
-		case XMDC_LABEL_BLUE  : sLabelSelection.color = &Blue; break;
-		case XMDC_LABEL_YELLOW: sLabelSelection.color = &Yellow; break;
-	} 
+  switch (sLabelSelection.CurColor) {
+    case XMDC_LABEL_RED   : sLabelSelection.color = &Red; break;
+    case XMDC_LABEL_GREEN : sLabelSelection.color = &Green; break;
+    case XMDC_LABEL_BLUE  : sLabelSelection.color = &Blue; break;
+    case XMDC_LABEL_YELLOW: sLabelSelection.color = &Yellow; break;
+  }
 
 
-	/* set the foreground to our color */
-	gdk_colormap_alloc_color(map,sLabelSelection.color, FALSE, TRUE);
-	gdk_gc_set_foreground(sLabelSelection.gc, sLabelSelection.color);
+  /* set the foreground to our color */
+  gdk_colormap_alloc_color(map,sLabelSelection.color, FALSE, TRUE);
+  gdk_gc_set_foreground(sLabelSelection.gc, sLabelSelection.color);
 
-	label=XMdcGetImageLabelTimes(nr);
+  label=XMdcGetImageLabelTimes(nr);
 
-	gdk_draw_string(widget->window, sfixed, sLabelSelection.gc, 2, 10, label);
+  gdk_draw_string(widget->window, sfixed, sLabelSelection.gc, 2, 10, label);
 
-	gdk_colormap_free_colors(map,sLabelSelection.color,1);
-	gdk_gc_destroy(sLabelSelection.gc);
+  gdk_colormap_free_colors(map,sLabelSelection.color,1);
+  gdk_gc_destroy(sLabelSelection.gc);
 }
 
 void XMdcLabelSelCallbackApply(GtkWidget *widget, gpointer data)
 {
-	gint color=XMDC_LABEL_YELLOW, state=MDC_YES, style=XMDC_LABEL_STYLE_PAGE;
-	if (GTK_TOGGLE_BUTTON(sLabelSelection.On)->active) {
-		MdcDebugPrint("labels: ON "); state = MDC_YES;
-	}else if (GTK_TOGGLE_BUTTON(sLabelSelection.Off)->active) {
-		MdcDebugPrint("labels: OFF "); state = MDC_NO;
-	}
+  gint color=XMDC_LABEL_YELLOW, state=MDC_YES, style=XMDC_LABEL_STYLE_PAGE;
+  if (GTK_TOGGLE_BUTTON(sLabelSelection.On)->active) {
+    MdcDebugPrint("labels: ON "); state = MDC_YES;
+  }else if (GTK_TOGGLE_BUTTON(sLabelSelection.Off)->active) {
+    MdcDebugPrint("labels: OFF "); state = MDC_NO;
+  }
 
-	MdcDebugPrint("label color: ");
-	if (GTK_TOGGLE_BUTTON(sLabelSelection.Red)->active) {
-		MdcDebugPrint("\tred"); color = XMDC_LABEL_RED;
-	}else if (GTK_TOGGLE_BUTTON(sLabelSelection.Green)->active) {
-		MdcDebugPrint("\tgreen"); color = XMDC_LABEL_GREEN;
-	}else if (GTK_TOGGLE_BUTTON(sLabelSelection.Blue)->active) {
-		MdcDebugPrint("\tblue"); color = XMDC_LABEL_BLUE;
-	}else if (GTK_TOGGLE_BUTTON(sLabelSelection.Yellow)->active) {
-		MdcDebugPrint("\tyellow"); color = XMDC_LABEL_YELLOW;
-	}
+  MdcDebugPrint("label color: ");
+  if (GTK_TOGGLE_BUTTON(sLabelSelection.Red)->active) {
+    MdcDebugPrint("\tred"); color = XMDC_LABEL_RED;
+  }else if (GTK_TOGGLE_BUTTON(sLabelSelection.Green)->active) {
+    MdcDebugPrint("\tgreen"); color = XMDC_LABEL_GREEN;
+  }else if (GTK_TOGGLE_BUTTON(sLabelSelection.Blue)->active) {
+    MdcDebugPrint("\tblue"); color = XMDC_LABEL_BLUE;
+  }else if (GTK_TOGGLE_BUTTON(sLabelSelection.Yellow)->active) {
+    MdcDebugPrint("\tyellow"); color = XMDC_LABEL_YELLOW;
+  }
 
-	MdcDebugPrint("label number: ");
-	if (GTK_TOGGLE_BUTTON(sLabelSelection.NrAbsolute)->active) {
-		MdcDebugPrint("\tabsolute"); style = XMDC_LABEL_STYLE_ABS;
-   }else if (GTK_TOGGLE_BUTTON(sLabelSelection.NrInPage)->active) {
-     MdcDebugPrint("\tin page");  style = XMDC_LABEL_STYLE_PAGE;
-   }else if (GTK_TOGGLE_BUTTON(sLabelSelection.NrEcat)->active) {
-     MdcDebugPrint("\tecat");     style = XMDC_LABEL_STYLE_ECAT;
-   }
+  MdcDebugPrint("label number: ");
+  if (GTK_TOGGLE_BUTTON(sLabelSelection.NrAbsolute)->active) {
+    MdcDebugPrint("\tabsolute"); style = XMDC_LABEL_STYLE_ABS;
+  }else if (GTK_TOGGLE_BUTTON(sLabelSelection.NrInPage)->active) {
+    MdcDebugPrint("\tin page");  style = XMDC_LABEL_STYLE_PAGE;
+  }else if (GTK_TOGGLE_BUTTON(sLabelSelection.NrEcat)->active) {
+    MdcDebugPrint("\tecat");     style = XMDC_LABEL_STYLE_ECAT;
+  }
 
-   if (state!=sLabelSelection.CurState || color!=sLabelSelection.CurColor ||
-       style!=sLabelSelection.CurStyle) {
-     sLabelSelection.CurState = state;
-     sLabelSelection.CurColor = color;
-     sLabelSelection.CurStyle = style;
-   }
+  if (state!=sLabelSelection.CurState || color!=sLabelSelection.CurColor ||
+      style!=sLabelSelection.CurStyle) {
+    sLabelSelection.CurState = state;
+    sLabelSelection.CurColor = color;
+    sLabelSelection.CurStyle = style;
+  }
 
-   /* MARK: need some kind of refresh signal here */
+  /* MARK: need some kind of refresh signal here */
    XMdcMainWidgetsInsensitive(); XMdcMainWidgetsResensitive();
 
 }
@@ -262,7 +262,7 @@ void XMdcLabelSel(void)
   GtkWidget *button;
   GtkWidget *separator;
   GSList *group;
-  
+
   if (wlabel == NULL) {
     wlabel = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
@@ -270,7 +270,7 @@ void XMdcLabelSel(void)
                        GTK_SIGNAL_FUNC(XMdcMedconQuit), NULL);
     gtk_signal_connect(GTK_OBJECT(wlabel),"delete_event",
                        GTK_SIGNAL_FUNC(XMdcHandlerToHide), NULL);
- 
+
 
     gtk_window_set_title(GTK_WINDOW(wlabel),"Label Selection");
     gtk_container_set_border_width(GTK_CONTAINER(wlabel),0);
@@ -302,7 +302,7 @@ void XMdcLabelSel(void)
     /* create radiobuttons */
     button = gtk_radio_button_new_with_label(NULL,"ON");
     gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
-    if (sLabelSelection.CurState == MDC_YES) 
+    if (sLabelSelection.CurState == MDC_YES)
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
 #ifdef GTKONE
     gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
@@ -421,7 +421,7 @@ void XMdcLabelSel(void)
     gtk_signal_connect(GTK_OBJECT(button), "clicked",
                        GTK_SIGNAL_FUNC(XMdcLabelSelCallbackApply), NULL);
     gtk_widget_show(button);
-  
+
     button = gtk_button_new_with_label("Cancel");
     gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
     gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
@@ -461,7 +461,7 @@ void XMdcLabelSel(void)
           gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b3),TRUE); break;
       case XMDC_LABEL_YELLOW:
           gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b4),TRUE); break;
-    } 
+    }
 
     b1 = sLabelSelection.NrAbsolute;
     b2 = sLabelSelection.NrInPage;
@@ -484,10 +484,9 @@ void XMdcLabelSel(void)
     XMdcUnsensitiveColNumFrames(NULL,NULL);
   }else{
     XMdcSensitiveColNumFrames(NULL,NULL);
-  }  
- 
+  }
+
   XMdcShowWidget(wlabel);
 
 }
 
-
