@@ -20,11 +20,11 @@
  *                XMdcGetHeaderInfo()             - Ask Hdr Info           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xreader.c,v 1.29 2011/12/27 00:46:06 enlf Exp $
+/* $Id$
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2019 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -63,7 +63,7 @@
 
 
 /****************************************************************************
-                              D E F I N E S 
+                              D E F I N E S
 ****************************************************************************/
 static RawReadSelectionStruct *raw = &sRawReadSelection;
 static MdcRawInputStruct *input = &mdcrawinput;
@@ -128,8 +128,8 @@ void XMdcRawReadFinish(guint otype)
   }
  /* change MedCon settings: disable quantifications, enable negative */
   MDC_QUANTIFY = MDC_NO; MDC_CALIBRATE = MDC_NO; MDC_NEGATIVE = MDC_YES;
- 
- 
+
+
   MdcGetColorMap(sColormapSelection.CurMap,my.fi->palette);
   msg = MdcImagesPixelFiddle(my.fi);
   if (msg != NULL) {
@@ -137,8 +137,8 @@ void XMdcRawReadFinish(guint otype)
     XMdcDisplayErr("Reading: %s",msg);
     XMdcProgressBar(MDC_PROGRESS_END,0.,NULL);
     return;
-  } 
-  
+  }
+
   XMDC_FILE_OPEN = MDC_YES; XMDC_FILE_TYPE = XMDC_RAW;
   XMdcViewerEnableAutoShrink();
   XMdcDisplayImages();
@@ -148,7 +148,7 @@ void XMdcRawReadFinish(guint otype)
   if (otype == XMDC_RAW)
     gtk_widget_destroy(sRawReadSelection.HdrInfoWindow);
 
-} 
+}
 
 void XMdcRawReadInteractive(GtkWidget *fs)
 {
@@ -199,16 +199,6 @@ void XMdcRawReadPredef(GtkWidget *fs)
     return;
   }
 
-  /* actually unused here, only identical images suppported */
-  input->abs_offset=(Uint32 *)malloc(my.fi->number*sizeof(Uint32));
-  if (input->abs_offset == NULL) {
-    MdcCleanUpFI(my.fi);
-    XMdcDisplayErr("Couldn't malloc abs_offset[]");
-    return;
-  }else{
-    memset(input->abs_offset,0,my.fi->number*sizeof(Uint32));
-  }
-
   for (i=0; i<my.fi->number; i++) {
      id = &my.fi->image[i];
      id->width = prev->XDIM;
@@ -223,7 +213,7 @@ void XMdcRawReadPredef(GtkWidget *fs)
     MDC_FILE_ENDIAN = MDC_HOST_ENDIAN;
   }
 
-  my.fi->endian = MDC_FILE_ENDIAN; 
+  my.fi->endian = MDC_FILE_ENDIAN;
   my.fi->dim[0] = 3;
   my.fi->dim[3] = my.fi->number;
   my.fi->diff_type = MDC_NO;
@@ -236,7 +226,6 @@ void XMdcRawReadPredef(GtkWidget *fs)
 
 void XMdcRawReadCancel(guint otype)
 {
-  MdcFree(input->abs_offset);
   MdcCleanUpFI(my.fi);
   if (otype == XMDC_RAW)
     gtk_widget_destroy(sRawReadSelection.HdrInfoWindow);
@@ -261,12 +250,10 @@ Int16 XMdcGetImageInfoPixelType(void)
     MdcDebugPrint("\tBIT32_S"); return(BIT32_S);
   }else if (GTK_TOGGLE_BUTTON(raw->typeBIT32_U)->active) {
     MdcDebugPrint("\tBT32_U"); return(BIT32_U);
-#ifdef HAVE_8BYTE_INT
   }else if (GTK_TOGGLE_BUTTON(raw->typeBIT64_S)->active) {
     MdcDebugPrint("\tBIT64_S"); return(BIT64_S);
   }else if (GTK_TOGGLE_BUTTON(raw->typeBIT64_U)->active) {
     MdcDebugPrint("\tBIT64_U"); return(BIT64_U);
-#endif 
   }else if (GTK_TOGGLE_BUTTON(raw->typeFLT32)->active) {
     MdcDebugPrint("\tFLT32"); return(FLT32);
   }else if (GTK_TOGGLE_BUTTON(raw->typeFLT64)->active) {
@@ -279,13 +266,13 @@ Int16 XMdcGetImageInfoPixelType(void)
 
   return(MDC_BAD_CODE);
 
-} 
+}
 /* Apply = Finish or Next */
 void XMdcGetImageInfoCallbackApply(void)
 {
   IMG_DATA *id=NULL;
   const char *entry;
-  Uint32 i, width, height, offset, imgnr;
+  Uint32 i, width, height, imgnr, offset;
   Int16 type;
 
   imgnr = raw->ImgCounter - 1;
@@ -314,28 +301,28 @@ void XMdcGetImageInfoCallbackApply(void)
   }
 
   if (input->DIFF) {
-    input->abs_offset[imgnr] = offset;
     id = &my.fi->image[imgnr];
+    id->load_location = (size_t)offset;
     id->width = width;
     id->height= height;
-    id->type  = type; 
+    id->type  = type;
     id->bits  = MdcType2Bits(id->type);
 
   }else{
 
     for (i=0; i<my.fi->number; i++) {
-       input->abs_offset[i] = offset;
        id = &my.fi->image[i];
+       id->load_location = (size_t)offset;
        id->width = width;
        id->height= height;
        id->type  = type;
        id->bits  = MdcType2Bits(id->type);
     }
-  } 
+  }
 
   if (raw->ImgCounter < my.fi->number) {
     /* next   -> get info for next image */
-    raw->ImgCounter += 1; 
+    raw->ImgCounter += 1;
     XMdcGetImageInfo();
   }else{
     /* finish -> read the file */
@@ -371,7 +358,7 @@ void XMdcGetImageInfo(void)
   gtk_window_set_title(GTK_WINDOW(window),"Input Image Info");
   gtk_widget_set_uposition(window,10,10);
   gtk_container_set_border_width(GTK_CONTAINER(window), 0);
- 
+
   box1 = gtk_vbox_new(FALSE, 0);
   gtk_container_add(GTK_CONTAINER(window),box1);
   gtk_container_set_border_width(GTK_CONTAINER(box1), 0);
@@ -414,7 +401,7 @@ void XMdcGetImageInfo(void)
   gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,0,1);
   gtk_widget_show(entry);
   raw->AbsOffset = entry;
- 
+
 
   /* Image dimensions */
   frame = gtk_frame_new("Dimensions (pixels)");
@@ -448,7 +435,7 @@ void XMdcGetImageInfo(void)
   label = gtk_label_new("   Rows ");
   gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_RIGHT);
   gtk_widget_set_name (label, "FixedLabel");
-  gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,1,2); 
+  gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,1,2);
   gtk_widget_show(label);
   entry = gtk_entry_new_with_max_length(5);
   sprintf(xmdcstr,"%u",prev->YDIM);
@@ -537,7 +524,6 @@ void XMdcGetImageInfo(void)
   }
   gtk_widget_show(button);
   raw->typeBIT32_U=button;
-#ifdef HAVE_8BYTE_INT
   group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
   button = gtk_radio_button_new_with_label(group,"Int64");
   gtk_table_attach_defaults(GTK_TABLE(table),button,0,1,4,5);
@@ -554,7 +540,6 @@ void XMdcGetImageInfo(void)
   }
   gtk_widget_show(button);
   raw->typeBIT64_U=button;
-#endif
   group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
   button = gtk_radio_button_new_with_label(group,"float");
   gtk_table_attach_defaults(GTK_TABLE(table),button,0,1,5,6);
@@ -655,7 +640,7 @@ void XMdcGetHeaderInfoCallbackApply(void)
   }else{
     input->REPEAT = MDC_NO;  prev->HDRREP = MDC_NO;
     MdcDebugPrint("image  header repeated = no");
-  } 
+  }
 
   /* swap pixel bytes */
   if (GTK_TOGGLE_BUTTON(raw->PixSwap)->active) {
@@ -677,15 +662,6 @@ void XMdcGetHeaderInfoCallbackApply(void)
     raw->ImgCounter = 1;
   }
 
-  input->abs_offset=(Uint32 *)malloc(my.fi->number*sizeof(Uint32));
-  if (input->abs_offset == NULL) {
-    XMdcRawReadCancel(XMDC_RAW);
-    XMdcDisplayErr("Couldn't malloc abs_offset[]");
-    return;
-  }else{
-    memset(input->abs_offset,0,my.fi->number*sizeof(Uint32));
-  }
-
   XMdcGetImageInfo();
 
 }
@@ -791,18 +767,18 @@ void XMdcGetHeaderInfo(void)
 
   button = gtk_check_button_new_with_label("Swap pixel bytes");
   gtk_box_pack_start(GTK_BOX(box3),button,TRUE,TRUE,0);
-  if (prev->PSWAP == MDC_YES) 
+  if (prev->PSWAP == MDC_YES)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   gtk_widget_show(button);
   raw->PixSwap = button;
 
   button = gtk_check_button_new_with_label("Identical images");
   gtk_box_pack_start(GTK_BOX(box3),button,TRUE,TRUE,0);
-  if (prev->DIFF == MDC_NO) 
+  if (prev->DIFF == MDC_NO)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
   gtk_widget_show(button);
   raw->ImgSame = button;
- 
+
   separator = gtk_hseparator_new();
   gtk_box_pack_start(GTK_BOX(box1),separator,FALSE,FALSE,0);
   gtk_widget_show(separator);
